@@ -49,133 +49,83 @@ extern int errno;
 #define AFS_CELLSERVDB AFS_CELLSERVDB_UNIX
 #endif /* DJGPP || WIN95 */
 
-static DWORD TraceOption = 0;
-
-/* This really needs to be initialized at DLL Init */
-#define TRACE_OPTION_EVENT 4
-
-#define ISCONFIGTRACE(v) ( ((v) & TRACE_OPTION_EVENT)==TRACE_OPTION_EVENT)
-
-void DebugEvent0_local(char *a) 
-{
-	HANDLE h; char *ptbuf[1];
-	if (!ISCONFIGTRACE(TraceOption))
-		return;
-	h = RegisterEventSource(NULL, a);
-	ptbuf[0] = a;
-	ReportEvent(h, EVENTLOG_INFORMATION_TYPE, 0, 0, NULL, 1, 0, (const char **)ptbuf, NULL);
-	DeregisterEventSource(h);
-}
-
-#define MAXBUF_ 512
-
-void DebugEvent_local(char *a,char *b,...) 
-{
-	HANDLE h; char *ptbuf[1],buf[MAXBUF_+1];
-	va_list marker;
-	if (!ISCONFIGTRACE(TraceOption))
-		return;
-	h = RegisterEventSource(NULL, a);
-	va_start(marker,b);
-	_vsnprintf(buf,MAXBUF_,b,marker);
-	ptbuf[0] = buf;
-	ReportEvent(h, EVENTLOG_INFORMATION_TYPE, 0, 0, NULL, 1, 0, (const char **)ptbuf, NULL);\
-	DeregisterEventSource(h);
-	va_end(marker);
-}
-
-#define REG_CLIENT_PARMS_KEY            TEXT("SYSTEM\\CurrentControlSet\\Services\\TransarcAFSDaemon\\Parameters")
-#define REG_CLIENT_TRACE_OPTION_PARM	TEXT("TraceOption")
-
-#ifdef COMMENT
-BOOL WINAPI DllMain (HANDLE hModule, DWORD fdwReason, LPVOID lpReserved)
-{
-    switch (fdwReason)
-    {
-    case DLL_PROCESS_ATTACH: {
-        DWORD LSPtype, LSPsize;
-        HKEY NPKey;
-
-        (void) RegOpenKeyEx(HKEY_LOCAL_MACHINE, AFSREG_CLT_SVC_PARAM_SUBKEY,
-                             0, KEY_QUERY_VALUE, &NPKey);
-        LSPsize=sizeof(TraceOption);
-        RegQueryValueEx(NPKey, REG_CLIENT_TRACE_OPTION_PARM, NULL,
-                        &LSPtype, (LPBYTE)&TraceOption, &LSPsize);
-
-        RegCloseKey (NPKey);
-        break;
-    }
-
-    case DLL_THREAD_ATTACH:
-        break;
-
-    case DLL_THREAD_DETACH:
-        break;
-
-    case DLL_PROCESS_DETACH:
-        break;
-
-    default:
-        return FALSE;
-    }
-
-    return TRUE;   // successful DLL_PROCESS_ATTACH
-}
-#endif /* COMMENT */
-
 static long cm_ParsePair(char *lineBufferp, char *leftp, char *rightp)
 {
-	char *tp;
+    char *tp;
     char tc;
     int sawEquals;
-	int sawBracket;
+    int sawBracket;
         
     sawEquals = 0;
-	sawBracket = 0;
+    sawBracket = 0;
     for(tp = lineBufferp; *tp; tp++) {
         tc = *tp;
 
-		if (sawBracket) {
-			if (tc == ']')
-				sawBracket = 0;
-			continue;
-		}
+	if (sawBracket) {
+	    if (tc == ']')
+		sawBracket = 0;
+	    continue;
+	}
 
-		/* comment or line end */
+	/* comment or line end */
         if (tc == '#' || tc == '\r' || tc == '\n') 
             break;
 
-		/* square bracket comment -- look for closing delim */
-		if (tc == '[') {
+	/* square bracket comment -- look for closing delim */
+	if (tc == '[') {
             sawBracket = 1; 
             continue;
-        }
+        }	
 
-		/* space or tab */
+	/* space or tab */
         if (tc == ' ' || tc == '\t') 
             continue;
 
         if (tc == '=') {
             sawEquals = 1;
             continue;
-		}
-                
+	}
+
         /* now we have a real character, put it in the appropriate bucket */
         if (sawEquals == 0) {
-			*leftp++ = tc;
-        }
-        else {
-			*rightp++ = tc;
+	    *leftp++ = tc;
+        }	
+        else {	
+	    *rightp++ = tc;
         }
     }
 
-	/* null terminate the strings */
-	*leftp = 0;
+    /* null terminate the strings */
+    *leftp = 0;
     *rightp = 0;
 
     return 0;	/* and return success */
 }
 
+static int
+IsWindowsModule(const char * name)
+{
+    const char * p;
+    int i;
+
+    /* Do not perform searches for probable Windows modules */
+    for (p = name, i=0; *p; p++) {
+	if ( *p == '.' )
+	    i++;
+    }
+    p = strrchr(name, '.');
+    if (p) {
+	if (i == 1 && 
+	    (!stricmp(p,".dll") ||
+	     !stricmp(p,".exe") ||
+	     !stricmp(p,".ini") ||
+	     !stricmp(p,".db") ||
+	     !stricmp(p,".drv")))
+	    return 1;
+    }
+    return 0;
+}
+
 /* search for a cell, and either return an error code if we don't find it,
  * or return 0 if we do, in which case we also fill in the addresses in
  * the cellp field.
@@ -198,12 +148,15 @@ long cm_SearchCellFile(char *cellNamep, char *newCellNamep,
     int inRightCell;
     int foundCell = 0;
     long code;
-	int tracking = 1, partial = 0;
+    int tracking = 1, partial = 0;
 #if defined(DJGPP) || defined(AFS_WIN95_ENV)
     char *afsconf_path;
     DWORD dwSize;
 #endif
 
+    if ( IsWindowsModule(cellNamep) )
+	return -3;
+
     cm_GetCellServDB(wdir);
     tfilep = fopen(wdir, "r");
 
@@ -226,7 +179,8 @@ long cm_SearchCellFile(char *cellNamep, char *newCellNamep,
         strcat(wdir, AFS_CELLSERVDB);
         /*fprintf(stderr, "opening cellservdb file %s\n", wdir);*/
         tfilep = fopen(wdir, "r");
-        if (!tfilep) return -2;
+        if (!tfilep) 
+	    return -2;
     }
 #else
     /* If we are NT or higher, we don't do DJGPP, So just fail */
@@ -234,40 +188,40 @@ long cm_SearchCellFile(char *cellNamep, char *newCellNamep,
         return -2;
 #endif
 
-	bestp = fopen(wdir, "r");
+    bestp = fopen(wdir, "r");
     
-#ifdef DEBUG
-    DebugEvent_local("AFS- cm_searchfile fopen", "Handle[%x], wdir[%s]", bestp, wdir);
+#ifdef CELLSERV_DEBUG
+    osi_Log2(afsd_logp,"cm_searchfile fopen handle[%p], wdir[%s]", bestp, 
+	     osi_LogSaveString(afsd_logp,wdir));
 #endif
-
-	/* have we seen the cell line for the guy we're looking for? */
-	inRightCell = 0;
-	while (1) {
+    /* have we seen the cell line for the guy we're looking for? */
+    inRightCell = 0;
+    while (1) {
         tp = fgets(lineBuffer, sizeof(lineBuffer), tfilep);
         if (tracking)
-			(void) fgets(lineBuffer, sizeof(lineBuffer), bestp);
-        if (tp == NULL) {
-			if (feof(tfilep)) {
-				/* hit EOF */
-				if (partial) {
-					/*
-					 * found partial match earlier;
-					 * now go back to it
-					 */
-					tempp = bestp;
-					bestp = tfilep;
-					tfilep = tempp;
-					inRightCell = 1;
-					partial = 0;
-					continue;
-				}
-				else {
-					fclose(tfilep);
-					fclose(bestp);
-					return (foundCell? 0 : -3);
-				}
-			}
-        }
+	    (void) fgets(lineBuffer, sizeof(lineBuffer), bestp);
+        if (	tp == NULL) {
+	    if (feof(tfilep)) {
+		/* hit EOF */
+		if (partial) {
+		    /*
+		     * found partial match earlier;
+		     * now go back to it
+		     */
+		    tempp = bestp;
+		    bestp = tfilep;
+		    tfilep = tempp;
+		    inRightCell = 1;
+		    partial = 0;
+		    continue;
+		}
+		else {
+		    fclose(tfilep);
+		    fclose(bestp);
+		    return (foundCell? 0 : -3);
+		}
+	    }
+        }	
 
         /* turn trailing cr or lf into null */
         tp = strchr(lineBuffer, '\r');
@@ -275,11 +229,11 @@ long cm_SearchCellFile(char *cellNamep, char *newCellNamep,
         tp = strchr(lineBuffer, '\n');
         if (tp) *tp = 0;
 
-		/* skip blank lines */
+	/* skip blank lines */
         if (lineBuffer[0] == 0) continue;
 
         if (lineBuffer[0] == '>') {
-			/* trim off at white space or '#' chars */
+	    /* trim off at white space or '#' chars */
             tp = strchr(lineBuffer, ' ');
             if (tp) *tp = 0;
             tp = strchr(lineBuffer, '\t');
@@ -287,84 +241,81 @@ long cm_SearchCellFile(char *cellNamep, char *newCellNamep,
             tp = strchr(lineBuffer, '#');
             if (tp) *tp = 0;
 
-			/* now see if this is the right cell */
+	    /* now see if this is the right cell */
             if (stricmp(lineBuffer+1, cellNamep) == 0) {
-				/* found the cell we're looking for */
-				if (newCellNamep)
-					strcpy(newCellNamep, lineBuffer+1);
+		/* found the cell we're looking for */
+		if (newCellNamep)
+		    strcpy(newCellNamep, lineBuffer+1);
                 inRightCell = 1;
-				tracking = 0;
-#ifdef DEBUG
-                DebugEvent_local("AFS- cm_searchfile is cell", "inRightCell[%x], linebuffer[%s]", 
-                                 inRightCell, lineBuffer);
+		tracking = 0;
+#ifdef CELLSERV_DEBUG                
+		osi_Log2(afsd_logp, "cm_searchfile is cell inRightCell[%p], linebuffer[%s]",
+			 inRightCell, osi_LogSaveString(afsd_logp,lineBuffer));
 #endif
-			}
-			else if (strnicmp(lineBuffer+1, cellNamep,
-                               strlen(cellNamep)) == 0) {
-				/* partial match */
-				if (partial) {	/* ambiguous */
-					fclose(tfilep);
-					fclose(bestp);
-					return -5;
-				}
-				if (newCellNamep)
-					strcpy(newCellNamep, lineBuffer+1);
-				inRightCell = 0;
-				tracking = 0;
-				partial = 1;
-			}
+	    }
+	    else if (strnicmp(lineBuffer+1, cellNamep,
+			       strlen(cellNamep)) == 0) {
+		/* partial match */
+		if (partial) {	/* ambiguous */
+		    fclose(tfilep);
+		    fclose(bestp);
+		    return -5;
+		}
+		if (newCellNamep)
+		    strcpy(newCellNamep, lineBuffer+1);
+		inRightCell = 0;
+		tracking = 0;
+		partial = 1;
+	    }
             else inRightCell = 0;
         }
         else {
 #if !defined(DJGPP) && !defined(AFS_WIN95_ENV)
             valuep = strchr(lineBuffer, '#');
-			if (valuep == NULL) {
-				fclose(tfilep);
-				fclose(bestp);
-				return -4;
-			}
+	    if (valuep == NULL) {
+		fclose(tfilep);
+		fclose(bestp);
+		return -4;
+	    }
             valuep++;	/* skip the "#" */
 
             valuep += strspn(valuep, " \t"); /* skip SP & TAB */
             /* strip spaces and tabs in the end. They should not be there according to CellServDB format
-            so do this just in case                        */
+             * so do this just in case                        
+	     */
             while (valuep[strlen(valuep) - 1] == ' ' || valuep[strlen(valuep) - 1] == '\t') 
                 valuep[strlen(valuep) - 1] = '\0';
 
 #endif /* !DJGPP */
-			if (inRightCell) {
+	    if (inRightCell) {
 #if !defined(DJGPP) && !defined(AFS_WIN95_ENV)
-				/* add the server to the VLDB list */
+		/* add the server to the VLDB list */
                 WSASetLastError(0);
                 thp = gethostbyname(valuep);
-#ifdef DEBUG
-                {
-                    int iErr = WSAGetLastError();
-                    DebugEvent_local("AFS- cm_searchfile inRightCell", 
-                                     "thp[%x], valuep[%s], WSAGetLastError[%d]", 
-                                     thp, valuep, iErr);
-                }
+#ifdef CELLSERV_DEBUG
+		osi_Log3(afsd_logp,"cm_searchfile inRightCell thp[%p], valuep[%s], WSAGetLastError[%d]",
+			 thp, osi_LogSaveString(afsd_logp,valuep), WSAGetLastError());
 #endif
-                if (thp) {
-					memcpy(&vlSockAddr.sin_addr.s_addr, thp->h_addr,
+		if (thp) {
+		    memcpy(&vlSockAddr.sin_addr.s_addr, thp->h_addr,
                             sizeof(long));
                     vlSockAddr.sin_family = AF_INET;
                     /* sin_port supplied by connection code */
-					if (procp)
-						(*procp)(rockp, &vlSockAddr, valuep);
+		    if (procp)
+			(*procp)(rockp, &vlSockAddr, valuep);
                     foundCell = 1;
-				}
+		}
 #else
                 thp = 0;
 #endif /* !DJGPP */
                 if (!thp) {
                     long ip_addr;
-					int c1, c2, c3, c4;
-					char aname[241] = "";                    
+		    int c1, c2, c3, c4;
+		    char aname[241] = "";                    
                     
                     /* Since there is no gethostbyname() data 
-                     * available we will read the IP address
-                     * stored in the CellServDB file
+		     * available we will read the IP address
+		     * stored in the CellServDB file
                      */
                     code = sscanf(lineBuffer, "%d.%d.%d.%d #%s",
                                    &c1, &c2, &c3, &c4, aname);
@@ -399,10 +350,11 @@ long cm_SearchCellByDNS(char *cellNamep, char *newCellNamep, int *ttl,
     int numServers;
     int i;
     struct sockaddr_in vlSockAddr;
-
-#ifdef DEBUG
-    DebugEvent_local("AFS SearchCellDNS-","Doing search for [%s]", cellNamep);
+#ifdef CELLSERV_DEBUG
+    osi_Log1(afsd_logp,"SearchCellDNS-Doing search for [%s]", osi_LogSaveString(afsd_logp,cellNamep));
 #endif
+    if ( IsWindowsModule(cellNamep) )
+	return -1;
     rc = getAFSServer(cellNamep, cellHostAddrs, cellHostNames, &numServers, ttl);
     if (rc == 0 && numServers > 0) {     /* found the cell */
         for (i = 0; i < numServers; i++) {
@@ -420,7 +372,7 @@ long cm_SearchCellByDNS(char *cellNamep, char *newCellNamep, int *ttl,
     else
        return -1;  /* not found */
 #else
-	return -1;  /* not found */
+    return -1;  /* not found */
 #endif /* AFS_AFSDB_ENV */
 }
 
@@ -451,7 +403,7 @@ long cm_GetCellServDB(char *cellNamep)
         strcpy(cellNamep, AFSDIR_CLIENT_ETC_DIRPATH);
 
     /* add trailing backslash, if required */
-    tlen = strlen(cellNamep);
+    tlen = (int)strlen(cellNamep);
     if (cellNamep[tlen-1] != '\\') 
         strcat(cellNamep, "\\");
 #else
@@ -528,63 +480,63 @@ long cm_GetRootCellName(char *cellNamep)
 
 cm_configFile_t *cm_CommonOpen(char *namep, char *rwp)
 {
-	char wdir[256];
+    char wdir[256];
     long tlen;
     FILE *tfilep;
 
 #if !defined(DJGPP) && !defined(AFS_WIN95_ENV)
     strcpy(wdir, AFSDIR_CLIENT_ETC_DIRPATH);
         
-	/* add trailing backslash, if required */
-        tlen = strlen(wdir);
-        if (wdir[tlen-1] != '\\') strcat(wdir, "\\");
+    /* add trailing backslash, if required */
+    tlen = (long)(strlen(wdir));
+    if (wdir[tlen-1] != '\\') strcat(wdir, "\\");
 #else
 #ifdef DJGPP
-        strcpy(wdir,cm_confDir);
+    strcpy(wdir,cm_confDir);
 #else
-        DWORD dwSize;
-        char *afsconf_path;
+    DWORD dwSize;
+    char *afsconf_path;
     
-        dwSize = GetEnvironmentVariable("AFSCONF", NULL, 0);
-        afsconf_path = malloc(dwSize);
-        dwSize = GetEnvironmentVariable("AFSCONF", afsconf_path, dwSize);
+    dwSize = GetEnvironmentVariable("AFSCONF", NULL, 0);
+    afsconf_path = malloc(dwSize);
+    dwSize = GetEnvironmentVariable("AFSCONF", afsconf_path, dwSize);
 
-        if (!afsconf_path)
-            strcpy(wdir, AFSDIR_CLIENT_ETC_DIRPATH);
-        else {
-            strcpy(wdir, afsconf_path);
-            free(afsconf_path);
-        }
+    if (!afsconf_path)
+	strcpy(wdir, AFSDIR_CLIENT_ETC_DIRPATH);
+    else {
+	strcpy(wdir, afsconf_path);
+	free(afsconf_path);
+    }
 #endif /* !DJGPP */
-        strcat(wdir,"/");
+    strcat(wdir,"/");
 #endif /* DJGPP || WIN95 */
 
-        strcat(wdir, namep);
+    strcat(wdir, namep);
         
-        tfilep = fopen(wdir, rwp);
+    tfilep = fopen(wdir, rwp);
 
-	return ((cm_configFile_t *) tfilep);        
-}
+    return ((cm_configFile_t *) tfilep);        
+}	
 
 #ifndef DJGPP
 long cm_WriteConfigString(char *labelp, char *valuep)
 {
-	DWORD code, dummyDisp;
-	HKEY parmKey;
+    DWORD code, dummyDisp;
+    HKEY parmKey;
 
-	code = RegCreateKeyEx(HKEY_LOCAL_MACHINE, AFSREG_CLT_SVC_PARAM_SUBKEY,
-				0, "container", 0, KEY_SET_VALUE, NULL,
-				&parmKey, &dummyDisp);
-	if (code != ERROR_SUCCESS)
-		return -1;
+    code = RegCreateKeyEx(HKEY_LOCAL_MACHINE, AFSREG_CLT_SVC_PARAM_SUBKEY,
+			   0, "container", 0, KEY_SET_VALUE, NULL,
+			   &parmKey, &dummyDisp);
+    if (code != ERROR_SUCCESS)
+	return -1;
 
-	code = RegSetValueEx(parmKey, labelp, 0, REG_SZ,
-			     valuep, strlen(valuep) + 1);
-	RegCloseKey (parmKey);
-	if (code != ERROR_SUCCESS)
-		return -1;
+    code = RegSetValueEx(parmKey, labelp, 0, REG_SZ,
+			  valuep, (DWORD)strlen(valuep) + 1);
+    RegCloseKey (parmKey);
+    if (code != ERROR_SUCCESS)
+	return (long)-1;
 
-        return 0;
+    return (long)0;
 }
 #endif /* !DJGPP */
 
@@ -715,7 +667,7 @@ long cm_CloseCellFile(cm_configFile_t *filep)
     strcpy(wdir, AFSDIR_CLIENT_ETC_DIRPATH);
         
 	/* add trailing backslash, if required */
-    tlen = strlen(wdir);
+    tlen = (int)strlen(wdir);
     if (wdir[tlen-1] != '\\') strcat(wdir, "\\");
 #else
 #ifdef DJGPP
@@ -769,7 +721,7 @@ void cm_GetConfigDir(char *dir)
     strcpy(wdir, AFSDIR_CLIENT_ETC_DIRPATH);
         
 	/* add trailing backslash, if required */
-    tlen = strlen(wdir);
+    tlen = (int)strlen(wdir);
     if (wdir[tlen-1] != '\\') strcat(wdir, "\\");
 #else
 #ifdef DJGPP
