@@ -241,7 +241,6 @@ rpc_t *rpc_create(int size_hint)
 {
     ULONG size;
     rpc_t *rpc;
-    ULONG status;
 
     size = sizeof(rpc_t) + 2*RPC_BUF_SIZE;
     rpc = malloc(size);
@@ -268,10 +267,8 @@ void rpc_destroy(rpc_t *rpc)
 
 rpc_transact(rpc_t *rpc)
 {
-    HANDLE hf;
-    int ret;
     ULONG header_len;
-    DWORD err, read = 0;
+    DWORD read = 0;
 
     if (!rpc)
         return IFSL_GENERIC_FAILURE;
@@ -286,6 +283,7 @@ rpc_transact(rpc_t *rpc)
 
 /* upcall stubs */
 #ifdef RPC_KERN
+long
 uc_namei(WCHAR *name, ULONG *fid)
 {
     rpc_t *rpc;
@@ -317,6 +315,7 @@ uc_namei(WCHAR *name, ULONG *fid)
     return status;
 }
 
+long
 uc_check_access(ULONG fid, ULONG access, ULONG *granted)
 {
     rpc_t *rpc;
@@ -345,6 +344,7 @@ uc_check_access(ULONG fid, ULONG access, ULONG *granted)
     return status;
 }
 
+long
 uc_create(WCHAR *name, ULONG attribs, LARGE_INTEGER alloc, ULONG access, ULONG *granted, ULONG *fid)
 {
     rpc_t *rpc;
@@ -375,6 +375,7 @@ uc_create(WCHAR *name, ULONG attribs, LARGE_INTEGER alloc, ULONG access, ULONG *
     return status;
 }
 
+long
 uc_stat(ULONG fid, ULONG *attribs, LARGE_INTEGER *size, LARGE_INTEGER *creation, LARGE_INTEGER *access, LARGE_INTEGER *change, LARGE_INTEGER *written)
 {
     rpc_t *rpc;
@@ -407,6 +408,7 @@ uc_stat(ULONG fid, ULONG *attribs, LARGE_INTEGER *size, LARGE_INTEGER *creation,
     return status;
 }
 
+long
 uc_setinfo(ULONG fid, ULONG attribs, LARGE_INTEGER creation, LARGE_INTEGER access, LARGE_INTEGER change, LARGE_INTEGER written)
 {
     rpc_t *rpc;
@@ -439,6 +441,7 @@ uc_setinfo(ULONG fid, ULONG attribs, LARGE_INTEGER creation, LARGE_INTEGER acces
     return status;
 }
 
+long
 uc_trunc(ULONG fid, LARGE_INTEGER size)
 {
     rpc_t *rpc;
@@ -466,6 +469,7 @@ uc_trunc(ULONG fid, LARGE_INTEGER size)
     return status;
 }
 
+long
 uc_read(ULONG fid, LARGE_INTEGER offset, ULONG length, ULONG *read, char *data)
 {
     rpc_t *rpc;
@@ -495,6 +499,7 @@ uc_read(ULONG fid, LARGE_INTEGER offset, ULONG length, ULONG *read, char *data)
     return status;
 }
 
+long
 uc_write(ULONG fid, LARGE_INTEGER offset, ULONG length, ULONG *written, char *data)
 {
     rpc_t *rpc;
@@ -524,6 +529,7 @@ uc_write(ULONG fid, LARGE_INTEGER offset, ULONG length, ULONG *written, char *da
     return status;
 }
 
+long
 uc_readdir(ULONG fid, LARGE_INTEGER cookie_in, WCHAR *filter, ULONG *count, char *data, ULONG *len)
 {
     rpc_t *rpc;
@@ -555,6 +561,7 @@ uc_readdir(ULONG fid, LARGE_INTEGER cookie_in, WCHAR *filter, ULONG *count, char
     return status;
 }
 
+long
 uc_close(ULONG fid)
 {
     rpc_t *rpc;
@@ -581,6 +588,7 @@ uc_close(ULONG fid)
     return status;
 }
 
+long
 uc_unlink(WCHAR *name)
 {
     rpc_t *rpc;
@@ -607,6 +615,7 @@ uc_unlink(WCHAR *name)
     return status;
 }
 
+long
 uc_ioctl_write(ULONG length, char *data, ULONG *key)
 {
     rpc_t *rpc;
@@ -634,6 +643,7 @@ uc_ioctl_write(ULONG length, char *data, ULONG *key)
     return status;
 }
 
+long
 uc_ioctl_read(ULONG key, ULONG *length, char *data)
 {
     rpc_t *rpc;
@@ -661,6 +671,7 @@ uc_ioctl_read(ULONG key, ULONG *length, char *data)
     return status;
 }
 
+long
 uc_rename(ULONG fid, WCHAR *curr, WCHAR *new_dir, WCHAR *new_name, ULONG *new_fid)
 {
     rpc_t *rpc;
@@ -691,6 +702,7 @@ uc_rename(ULONG fid, WCHAR *curr, WCHAR *new_dir, WCHAR *new_name, ULONG *new_fi
     return status;
 }
 
+long
 uc_flush(ULONG fid)
 {
     rpc_t *rpc;
@@ -721,7 +733,7 @@ uc_flush(ULONG fid)
 
 /* downcall stubs */
 #ifndef RPC_KERN
-dc_break_callback(ULONG fid)
+long dc_break_callback(ULONG fid)
 {
     rpc_t *rpc;
     ULONG status;
@@ -742,7 +754,7 @@ dc_break_callback(ULONG fid)
     return status;
 }
 
-dc_release_hooks()
+long dc_release_hooks(void)
 {
     rpc_t *rpc;
     ULONG status;
@@ -1225,7 +1237,6 @@ rpc_parse(rpc_t *rpc)
         break;
     case RPC_UNLINK:
         {
-            ULONG fid, unlink;
             rpc_unmarshal_wstr(rpc, name);
             status = uc_unlink(name);
             rpc_marshal_long(rpc, status);
