@@ -25,17 +25,20 @@ extern "C" {
 #include "down_servers_dlg.h"
 
 extern "C" {
-#include <afs/param.h>
-#include <osi.h>
+#include <rx/rx_globals.h>
 #include "fs.h"
 #include "fs_utils.h"
 #include <afsint.h>
+#include <afs/cellconfig.h>
+#include <afs/vldbint.h>
+#include <afs/volser.h>
 #include <afs/auth.h>
+#include <WINNT\afsreg.h>
+#include <cm.h>
 }
 
-
 #define PCCHAR(str)		((char *)(const char *)(str))
-
+#define VL_NOENT                (363524L)
 
 #define	MAXHOSTS 13
 #define	OMAXHOSTS 8
@@ -48,24 +51,32 @@ extern "C" {
 #define MAXHOSTCHARS		64
 #define MAXHOSTSPERCELL		8
 
-struct afsconf_cell {
-	char name[MAXCELLCHARS];
-    short numServers;
-    short flags;
-    struct sockaddr_in hostAddr[MAXHOSTSPERCELL];
-    char hostName[MAXHOSTSPERCELL][MAXHOSTCHARS];
-    char *linkedCell;
-};
-
 static char space[MAXSIZE];
 static char tspace[1024];
 
+static struct ubik_client *uclient;
+static int rxInitDone = 0;
+static char pn[] = "fs";
+
 // #define	LOGGING_ON		// Enable this to log certain pioctl calls
 
 #ifdef	LOGGING_ON
 static char *szLogFileName = "afsguilog.txt";
 #endif
 
+static int
+VLDBInit(int noAuthFlag, struct afsconf_cell *info)
+{
+    afs_int32 code;
+
+    code = ugen_ClientInit(noAuthFlag, (char *)AFSDIR_CLIENT_ETC_DIRPATH, 
+			   info->name, 0, &uclient, 
+                           NULL, pn, rxkad_clear,
+                           VLDB_MAXSERVERS, AFSCONF_VLDBSERVICE, 50,
+                           0, 0, USER_SERVICE_ID);
+    rxInitDone = 1;
+    return code;
+}
 
 FILE *OpenFile(char *file, char *rwp)
 {
@@ -124,14 +135,14 @@ void Flush(const CStringArray& files)
         if (code) {
             error = 1;
             if (errno == EMFILE)
-                ShowMessageBox(IDS_FLUSH_FAILED, MB_ICONEXCLAMATION, IDS_FLUSH_FAILED, files[i]);
+                ShowMessageBox(IDS_FLUSH_FAILED, MB_ICONERROR, IDS_FLUSH_FAILED, files[i]);
             else 
-                ShowMessageBox(IDS_FLUSH_ERROR, MB_ICONEXCLAMATION, IDS_FLUSH_ERROR, files[i], strerror(errno));
+                ShowMessageBox(IDS_FLUSH_ERROR, MB_ICONERROR, IDS_FLUSH_ERROR, files[i], strerror(errno));
         }
     }   
 
     if (!error)
-        ShowMessageBox(IDS_FLUSH_OK, MB_ICONEXCLAMATION, IDS_FLUSH_OK);
+        ShowMessageBox(IDS_FLUSH_OK, MB_ICONINFORMATION, IDS_FLUSH_OK);
 }       
 
 void FlushVolume(const CStringArray& files)
@@ -148,12 +159,12 @@ void FlushVolume(const CStringArray& files)
         code = pioctl(PCCHAR(files[i]), VIOC_FLUSHVOLUME, &blob, 0);
         if (code) {
             error = 1;
-            ShowMessageBox(IDS_FLUSH_VOLUME_ERROR, MB_ICONEXCLAMATION, IDS_FLUSH_VOLUME_ERROR, files[i], strerror(errno));
+            ShowMessageBox(IDS_FLUSH_VOLUME_ERROR, MB_ICONERROR, IDS_FLUSH_VOLUME_ERROR, files[i], strerror(errno));
         }
     }   
 
     if (!code)
-        ShowMessageBox(IDS_FLUSH_VOLUME_OK, MB_ICONEXCLAMATION, IDS_FLUSH_VOLUME_OK);
+        ShowMessageBox(IDS_FLUSH_VOLUME_OK, MB_ICONINFORMATION, IDS_FLUSH_VOLUME_OK);
 }       
 
 void WhichCell(CStringArray& files)
@@ -223,11 +234,11 @@ BOOL CheckVolumes()
     blob.out_size = 0;
     code = pioctl(0, VIOCCKBACK, &blob, 1);
     if (code) {
-        ShowMessageBox(IDS_CHECK_VOLUMES_ERROR, MB_ICONEXCLAMATION, IDS_CHECK_VOLUMES_ERROR, GetAfsError(errno, CString()));
+        ShowMessageBox(IDS_CHECK_VOLUMES_ERROR, MB_ICONERROR, IDS_CHECK_VOLUMES_ERROR, GetAfsError(errno, CString()));
         return FALSE;
     }
 
-    ShowMessageBox(IDS_CHECK_VOLUMES_OK, MB_OK, IDS_CHECK_VOLUMES_OK);
+    ShowMessageBox(IDS_CHECK_VOLUMES_OK, MB_OK|MB_ICONINFORMATION, IDS_CHECK_VOLUMES_OK);
 
     return TRUE;
 }
@@ -298,10 +309,54 @@ void WhereIs(CStringArray& files)
     dlg.DoModal();
 }       
 
+static int
+CMtoUNIXerror(int cm_code)
+{
+    switch (cm_code) {
+    case CM_ERROR_TIMEDOUT:
+	return ETIMEDOUT;
+    case CM_ERROR_NOACCESS:
+	return EACCES;
+    case CM_ERROR_NOSUCHFILE:
+	return ENOENT;
+    case CM_ERROR_INVAL:
+	return EINVAL;
+    case CM_ERROR_BADFD:
+	return EBADF;
+    case CM_ERROR_EXISTS:
+	return EEXIST;
+    case CM_ERROR_CROSSDEVLINK:
+	return EXDEV;
+    case CM_ERROR_NOTDIR:
+	return ENOTDIR;
+    case CM_ERROR_ISDIR:
+	return EISDIR;
+    case CM_ERROR_READONLY:
+	return EROFS;
+    case CM_ERROR_WOULDBLOCK:
+	return EWOULDBLOCK;
+    case CM_ERROR_NOSUCHCELL:
+	return ESRCH;		/* hack */
+    case CM_ERROR_NOSUCHVOLUME:
+	return EPIPE;		/* hack */
+    case CM_ERROR_NOMORETOKENS:
+	return EDOM;		/* hack */
+    case CM_ERROR_TOOMANYBUFS:
+	return EFBIG;		/* hack */
+    default:
+	if (cm_code > 0 && cm_code < EILSEQ)
+	    return cm_code;
+	else
+	    return ENOTTY;
+    }
+}
+
 CString GetAfsError(int code, const char *filename)
 {
     CString strMsg;
 
+    code = CMtoUNIXerror(code);
+
     if (code == EINVAL) {
         if (filename)
             strMsg.Format("Invalid argument; it is possible that the file is not in AFS");
@@ -606,7 +661,7 @@ void CleanACL(CStringArray& names)
     struct ViceIoctl blob;
     int changes;
 
-    ShowMessageBox(IDS_CLEANACL_MSG, MB_OK, IDS_CLEANACL_MSG);
+    ShowMessageBox(IDS_CLEANACL_MSG, MB_OK|MB_ICONINFORMATION, IDS_CLEANACL_MSG);
 
     HOURGLASS hourglass;
 
@@ -617,13 +672,13 @@ void CleanACL(CStringArray& names)
 
         code = pioctl(PCCHAR(names[i]), VIOCGETAL, &blob, 1);
         if (code) {
-            ShowMessageBox(IDS_CLEANACL_ERROR, MB_ICONEXCLAMATION, 0, names[i], GetAfsError(errno));
+            ShowMessageBox(IDS_CLEANACL_ERROR, MB_ICONERROR, 0, names[i], GetAfsError(errno));
             continue;
         }
 
         ta = ParseAcl(space);
         if (ta->dfs) {
-            ShowMessageBox(IDS_CLEANACL_NOT_SUPPORTED, MB_ICONEXCLAMATION, IDS_CLEANACL_NOT_SUPPORTED, names[i]);
+            ShowMessageBox(IDS_CLEANACL_NOT_SUPPORTED, MB_ICONERROR, IDS_CLEANACL_NOT_SUPPORTED, names[i]);
             continue;
         }
 
@@ -639,11 +694,11 @@ void CleanACL(CStringArray& names)
         code = pioctl(PCCHAR(names[i]), VIOCSETAL, &blob, 1);
         if (code) {
             if (errno == EINVAL) {
-                ShowMessageBox(IDS_CLEANACL_INVALID_ARG, MB_ICONEXCLAMATION, IDS_CLEANACL_INVALID_ARG, names[i]);
+                ShowMessageBox(IDS_CLEANACL_INVALID_ARG, MB_ICONERROR, IDS_CLEANACL_INVALID_ARG, names[i]);
                 continue;
             }
             else {
-                ShowMessageBox(IDS_CLEANACL_ERROR, MB_ICONEXCLAMATION, 0, names[i], GetAfsError(errno));
+                ShowMessageBox(IDS_CLEANACL_ERROR, MB_ICONERROR, 0, names[i], GetAfsError(errno));
                 continue;
             }
         }
@@ -667,13 +722,13 @@ BOOL GetRights(const CString& strDir, CStringArray& strNormal, CStringArray& str
 	
     code = pioctl(PCCHAR(strDir), VIOCGETAL, &blob, 1);
     if (code) {
-        ShowMessageBox(IDS_GETRIGHTS_ERROR, MB_ICONEXCLAMATION, IDS_GETRIGHTS_ERROR, strDir, GetAfsError(errno));
+        ShowMessageBox(IDS_GETRIGHTS_ERROR, MB_ICONERROR, IDS_GETRIGHTS_ERROR, strDir, GetAfsError(errno));
         return FALSE;
     }
 
     ta = ParseAcl(space);
     if (ta->dfs) {
-        ShowMessageBox(IDS_DFSACL_ERROR, MB_ICONEXCLAMATION, IDS_DFSACL_ERROR);
+        ShowMessageBox(IDS_DFSACL_ERROR, MB_ICONERROR, IDS_DFSACL_ERROR);
         return FALSE;
     }
 
@@ -833,9 +888,9 @@ BOOL SaveACL(const CString& strCellName, const CString& strDir, const CStringArr
     code = pioctl(PCCHAR(strDir), VIOCSETAL, &blob, 1);
     if (code) {
         if (errno == EINVAL)
-            ShowMessageBox(IDS_SAVE_ACL_EINVAL_ERROR, MB_ICONEXCLAMATION, IDS_SAVE_ACL_EINVAL_ERROR, strDir);
+            ShowMessageBox(IDS_SAVE_ACL_EINVAL_ERROR, MB_ICONERROR, IDS_SAVE_ACL_EINVAL_ERROR, strDir);
         else
-            ShowMessageBox(IDS_SAVE_ACL_ERROR, MB_ICONEXCLAMATION, IDS_SAVE_ACL_ERROR, strDir, GetAfsError(errno, strDir));
+            ShowMessageBox(IDS_SAVE_ACL_ERROR, MB_ICONERROR, IDS_SAVE_ACL_ERROR, strDir, GetAfsError(errno, strDir));
     }       
 
     ZapAcl(pAcl);
@@ -859,7 +914,7 @@ BOOL CopyACL(const CString& strToDir, const CStringArray& normal, const CStringA
 	
     code = pioctl(PCCHAR(strToDir), VIOCGETAL, &blob, 1);
     if (code) {
-        ShowMessageBox(IDS_ACL_READ_ERROR, MB_ICONEXCLAMATION, IDS_ACL_READ_ERROR, strToDir, GetAfsError(errno, strToDir));
+        ShowMessageBox(IDS_ACL_READ_ERROR, MB_ICONERROR, IDS_ACL_READ_ERROR, strToDir, GetAfsError(errno, strToDir));
         return FALSE;
     }
 	
@@ -871,7 +926,7 @@ BOOL CopyACL(const CString& strToDir, const CStringArray& normal, const CStringA
     CleanAcl(pToAcl);
 
     if (pToAcl->dfs) {
-        ShowMessageBox(IDS_NO_DFS_COPY_ACL, MB_ICONEXCLAMATION, IDS_NO_DFS_COPY_ACL, strToDir);
+        ShowMessageBox(IDS_NO_DFS_COPY_ACL, MB_ICONERROR, IDS_NO_DFS_COPY_ACL, strToDir);
         ZapAcl(pToAcl);
         return FALSE;
     }
@@ -900,15 +955,15 @@ BOOL CopyACL(const CString& strToDir, const CStringArray& normal, const CStringA
     if (code) {
         ZapAcl(pToAcl);
         if (errno == EINVAL)
-            ShowMessageBox(IDS_COPY_ACL_EINVAL_ERROR, MB_ICONEXCLAMATION, IDS_COPY_ACL_EINVAL_ERROR, strToDir);
+            ShowMessageBox(IDS_COPY_ACL_EINVAL_ERROR, MB_ICONERROR, IDS_COPY_ACL_EINVAL_ERROR, strToDir);
         else 
-            ShowMessageBox(IDS_COPY_ACL_ERROR, MB_ICONEXCLAMATION, IDS_COPY_ACL_ERROR, strToDir, GetAfsError(errno, strToDir));
+            ShowMessageBox(IDS_COPY_ACL_ERROR, MB_ICONERROR, IDS_COPY_ACL_ERROR, strToDir, GetAfsError(errno, strToDir));
         return FALSE;
     }
 
     ZapAcl(pToAcl);
 
-    ShowMessageBox(IDS_COPY_ACL_OK, MB_OK, IDS_COPY_ACL_OK);
+    ShowMessageBox(IDS_COPY_ACL_OK, MB_OK|MB_ICONINFORMATION, IDS_COPY_ACL_OK);
 
     return TRUE;
 }
@@ -937,6 +992,228 @@ CString ParseMountPoint(const CString strFile, CString strMountPoint)
     return strMountPointInfo;
 }       
 
+BOOL IsPathInAfs(const CHAR *strPath)
+{
+    struct ViceIoctl blob;
+    int code;
+
+    HOURGLASS hourglass;
+
+    blob.in_size = 0;
+    blob.out_size = MAXSIZE;
+    blob.out = space;
+
+    code = pioctl((LPTSTR)((LPCTSTR)strPath), VIOC_FILE_CELL_NAME, &blob, 1);
+    if (code)
+        return FALSE;
+    return TRUE;
+}
+
+static int 
+IsFreelanceRoot(char *apath)
+{
+    struct ViceIoctl blob;
+    afs_int32 code;
+
+    blob.in_size = 0;
+    blob.out_size = MAXSIZE;
+    blob.out = space;
+
+    code = pioctl(apath, VIOC_FILE_CELL_NAME, &blob, 1);
+    if (code == 0)
+        return !strcmp("Freelance.Local.Root",space);
+    return 1;   /* assume it is because it is more restrictive that way */
+}
+
+const char * NetbiosName(void)
+{
+    static char buffer[1024] = "AFS";
+    HKEY  parmKey;
+    DWORD code;
+    DWORD dummyLen;
+    DWORD enabled = 0;
+
+    code = RegOpenKeyEx(HKEY_LOCAL_MACHINE, AFSREG_CLT_SVC_PARAM_SUBKEY,
+                         0, KEY_QUERY_VALUE, &parmKey);
+    if (code == ERROR_SUCCESS) {
+        dummyLen = sizeof(buffer);
+        code = RegQueryValueEx(parmKey, "NetbiosName", NULL, NULL,
+			       (LPBYTE)buffer, &dummyLen);
+        RegCloseKey (parmKey);
+    } else {
+	strcpy(buffer, "AFS");
+    }
+    return buffer;
+}
+
+#define AFSCLIENT_ADMIN_GROUPNAME "AFS Client Admins"
+
+static BOOL IsAdmin (void)
+{
+    static BOOL fAdmin = FALSE;
+    static BOOL fTested = FALSE;
+
+    if (!fTested)
+    {
+        /* Obtain the SID for the AFS client admin group.  If the group does
+         * not exist, then assume we have AFS client admin privileges.
+         */
+        PSID psidAdmin = NULL;
+        DWORD dwSize, dwSize2;
+        char pszAdminGroup[ MAX_COMPUTERNAME_LENGTH + sizeof(AFSCLIENT_ADMIN_GROUPNAME) + 2 ];
+        char *pszRefDomain = NULL;
+        SID_NAME_USE snu = SidTypeGroup;
+
+        dwSize = sizeof(pszAdminGroup);
+
+        if (!GetComputerName(pszAdminGroup, &dwSize)) {
+            /* Can't get computer name.  We return false in this case.
+               Retain fAdmin and fTested. This shouldn't happen.*/
+            return FALSE;
+        }
+
+        dwSize = 0;
+        dwSize2 = 0;
+
+        strcat(pszAdminGroup,"\\");
+        strcat(pszAdminGroup, AFSCLIENT_ADMIN_GROUPNAME);
+
+        LookupAccountName(NULL, pszAdminGroup, NULL, &dwSize, NULL, &dwSize2, &snu);
+        /* that should always fail. */
+
+        if (GetLastError() != ERROR_INSUFFICIENT_BUFFER) {
+            /* if we can't find the group, then we allow the operation */
+            fAdmin = TRUE;
+            return TRUE;
+        }
+
+        if (dwSize == 0 || dwSize2 == 0) {
+            /* Paranoia */
+            fAdmin = TRUE;
+            return TRUE;
+        }
+
+        psidAdmin = (PSID)malloc(dwSize); memset(psidAdmin,0,dwSize);
+        pszRefDomain = (char *)malloc(dwSize2);
+
+        if (!LookupAccountName(NULL, pszAdminGroup, psidAdmin, &dwSize, pszRefDomain, &dwSize2, &snu)) {
+            /* We can't lookup the group now even though we looked it up earlier.  
+               Could this happen? */
+            fAdmin = TRUE;
+        } else {
+            /* Then open our current ProcessToken */
+            HANDLE hToken;
+
+            if (OpenProcessToken (GetCurrentProcess(), TOKEN_QUERY, &hToken))
+            {
+
+                if (!CheckTokenMembership(hToken, psidAdmin, &fAdmin)) {
+                    /* We'll have to allocate a chunk of memory to store the list of
+                     * groups to which this user belongs; find out how much memory
+                     * we'll need.
+                     */
+                    DWORD dwSize = 0;
+                    PTOKEN_GROUPS pGroups;
+
+                    GetTokenInformation (hToken, TokenGroups, NULL, dwSize, &dwSize);
+
+                    pGroups = (PTOKEN_GROUPS)malloc(dwSize);
+
+                    /* Allocate that buffer, and read in the list of groups. */
+                    if (GetTokenInformation (hToken, TokenGroups, pGroups, dwSize, &dwSize))
+                    {
+                        /* Look through the list of group SIDs and see if any of them
+                         * matches the AFS Client Admin group SID.
+                         */
+                        size_t iGroup = 0;
+                        for (; (!fAdmin) && (iGroup < pGroups->GroupCount); ++iGroup)
+                        {
+                            if (EqualSid (psidAdmin, pGroups->Groups[ iGroup ].Sid)) {
+                                fAdmin = TRUE;
+                            }
+                        }
+                    }
+
+                    if (pGroups)
+                        free(pGroups);
+                }
+
+                /* if do not have permission because we were not explicitly listed
+                 * in the Admin Client Group let's see if we are the SYSTEM account
+                 */
+                if (!fAdmin) {
+                    PTOKEN_USER pTokenUser;
+                    SID_IDENTIFIER_AUTHORITY SIDAuth = SECURITY_NT_AUTHORITY;
+                    PSID pSidLocalSystem = 0;
+                    DWORD gle;
+
+                    GetTokenInformation(hToken, TokenUser, NULL, 0, &dwSize);
+
+                    pTokenUser = (PTOKEN_USER)malloc(dwSize);
+
+                    if (!GetTokenInformation(hToken, TokenUser, pTokenUser, dwSize, &dwSize))
+                        gle = GetLastError();
+
+                    if (AllocateAndInitializeSid( &SIDAuth, 1,
+                                                  SECURITY_LOCAL_SYSTEM_RID,
+                                                  0, 0, 0, 0, 0, 0, 0,
+                                                  &pSidLocalSystem))
+                    {
+                        if (EqualSid(pTokenUser->User.Sid, pSidLocalSystem)) {
+                            fAdmin = TRUE;
+                        }
+
+                        FreeSid(pSidLocalSystem);
+                    }
+
+                    if ( pTokenUser )
+                        free(pTokenUser);
+                }
+            }
+        }
+
+        free(psidAdmin);
+        free(pszRefDomain);
+
+        fTested = TRUE;
+    }
+
+    return fAdmin;
+}
+
+/* return a static pointer to a buffer */
+static char *Parent(char *apath)
+{
+    register char *tp;
+
+    strcpy(tspace, apath);
+    tp = strrchr(tspace, '\\');
+    if (tp) {
+        *(tp+1) = 0;	/* lv trailing slash so Parent("k:\foo") is "k:\" not "k:" */
+    }
+    else {
+        fs_ExtractDriveLetter(apath, tspace);
+    	strcat(tspace, ".");
+    }
+    
+    return tspace;
+}
+
+static afs_int32
+GetCell(char *fname, char *cellname)
+{
+    afs_int32 code;
+    struct ViceIoctl blob;
+
+    blob.in_size = 0;
+    blob.out_size = MAXCELLCHARS;
+    blob.out = cellname;
+
+    code = pioctl(fname, VIOC_FILE_CELL_NAME, &blob, 1);
+    return code ? errno : 0;
+}
+
+
 BOOL ListMount(CStringArray& files)
 {
     register LONG code;
@@ -968,6 +1245,19 @@ BOOL ListMount(CStringArray& files)
             strncpy(parent_dir, true_name, last_component - true_name + 1);
             parent_dir[last_component - true_name + 1] = 0;
             last_component++;   /* Skip the slash */
+
+	    if (!IsPathInAfs(parent_dir)) {
+		const char * nbname = NetbiosName();
+		int len = strlen(nbname);
+
+		if (parent_dir[0] == '\\' && parent_dir[1] == '\\' &&
+		    parent_dir[len+2] == '\\' &&
+		    parent_dir[len+3] == '\0' &&
+		    !strnicmp(nbname,&parent_dir[2],len))
+		{
+		    sprintf(parent_dir,"\\\\%s\\all\\", nbname);
+		}
+	    }
         }
         else {
             /*
@@ -1008,80 +1298,90 @@ BOOL ListMount(CStringArray& files)
     return !error;
 }
 
-BOOL IsPathInAfs(const CHAR *strPath)
-{
-    struct ViceIoctl blob;
-    int code;
-
-    HOURGLASS hourglass;
-
-    blob.in_size = 0;
-    blob.out_size = MAXSIZE;
-    blob.out = space;
-
-    code = pioctl((LPTSTR)((LPCTSTR)strPath), VIOC_FILE_CELL_NAME, &blob, 1);
-    if (code)
-        return FALSE;
-    return TRUE;
-}
-
-/* return a static pointer to a buffer */
-static char *Parent(char *apath)
-{
-    register char *tp;
-
-    strcpy(tspace, apath);
-    tp = strrchr(tspace, '\\');
-    if (tp) {
-        *(tp+1) = 0;	/* lv trailing slash so Parent("k:\foo") is "k:\" not "k:" */
-    }
-    else {
-        fs_ExtractDriveLetter(apath, tspace);
-    	strcat(tspace, ".");
-    }
-    
-    return tspace;
-}
-
 BOOL MakeMount(const CString& strDir, const CString& strVolName, const CString& strCellName, BOOL bRW)
 {
     register LONG code;
     register char *cellName;
-    char localCellName[1000];
+    char localCellName[128];
+    struct afsconf_cell info;
+#if 0
+    struct vldbentry vldbEntry;
+#endif
     struct ViceIoctl blob;
+    char * parent;
+    char path[1024] = "";
 
     HOURGLASS hourglass;
 
     ASSERT(strVolName.GetLength() < 64);
 
-    /*
-
-    defect #3069
-
-    if (as->parms[5].items && !as->parms[2].items) {
-	fprintf(stderr,"fs: must provide cell when creating cellular mount point.\n");
-	return FALSE;
-    }
-    */
-
     if (strCellName.GetLength() > 0)	/* cell name specified */
         cellName = PCCHAR(strCellName);
     else
         cellName = (char *) 0;
 
-    if (!IsPathInAfs(Parent(PCCHAR(strDir)))) {
-        ShowMessageBox(IDS_MAKE_MP_NOT_AFS_ERROR, MB_ICONEXCLAMATION, IDS_MAKE_MP_NOT_AFS_ERROR);
-        return FALSE;
+    parent = Parent(PCCHAR(strDir));
+    if (!IsPathInAfs(parent)) {
+	const char * nbname = NetbiosName();
+	int len = strlen(nbname);
+
+	if (parent[0] == '\\' && parent[1] == '\\' &&
+	    parent[len+2] == '\\' &&
+	    parent[len+3] == '\0' &&
+	    !strnicmp(nbname,&parent[2],len))
+	{
+	    sprintf(path,"%sall\\%s", parent, &(PCCHAR(strDir)[strlen(parent)]));
+	    parent = Parent(path);
+	    if (!IsPathInAfs(parent)) {
+		ShowMessageBox(IDS_MAKE_MP_NOT_AFS_ERROR, MB_ICONERROR, IDS_MAKE_MP_NOT_AFS_ERROR);
+		return FALSE;
+	    }
+	} else {
+	    ShowMessageBox(IDS_MAKE_MP_NOT_AFS_ERROR, MB_ICONERROR, IDS_MAKE_MP_NOT_AFS_ERROR);
+	    return FALSE;
+	}
     }
 
-    if (cellName) {
-        blob.in_size = 0;
-        blob.out_size = MAXSIZE;
-        blob.out = space;
-        code = pioctl(Parent(PCCHAR(strDir)), VIOC_FILE_CELL_NAME, &blob, 1);
-    }   
+    if ( strlen(path) == 0 )
+	strcpy(path, PCCHAR(strDir));
 
-    strcpy(localCellName, (cellName? cellName : space));
+    if ( IsFreelanceRoot(parent) ) {
+	if ( !IsAdmin() ) {
+	    ShowMessageBox(IDS_NOT_AFS_CLIENT_ADMIN_ERROR, MB_ICONERROR, IDS_NOT_AFS_CLIENT_ADMIN_ERROR);
+	    return FALSE;
+	}
+
+	if (!cellName) {
+	    blob.in_size = 0;
+	    blob.out_size = sizeof(localCellName);
+	    blob.out = localCellName;
+	    code = pioctl(parent, VIOC_GET_WS_CELL, &blob, 1);
+	    if (!code)
+		cellName = localCellName;
+	}
+    } else {
+	if (!cellName)
+	    GetCell(parent,space);
+    }
+
+    code = GetCellName(cellName?cellName:space, &info);
+    if (code) {
+	return FALSE;
+    }
+
+#if 0
+    code = VLDBInit(1, &info);
+    if (code == 0) {
+	/* make the check.  Don't complain if there are problems with init */
+	code = ubik_VL_GetEntryByNameO(uclient, 0, PCCHAR(strVolName), &vldbEntry);
+	if (code == VL_NOENT) {
+	    ShowMessageBox(IDS_WARNING, MB_ICONWARNING, IDS_VOLUME_NOT_IN_CELL_WARNING, 
+			    PCCHAR(strVolName), cellName ? cellName : space);
+	}
+    }
+    if (rxInitDone) 
+        rx_Finalize();
+#endif
 
     if (bRW)	/* if -rw specified */
         strcpy(space, "%");
@@ -1090,7 +1390,7 @@ BOOL MakeMount(const CString& strDir, const CString& strVolName, const CString&
 
     /* If cellular mount point, prepend cell prefix */
     if (cellName) {
-        strcat(space, localCellName);
+        strcat(space, info.name);
         strcat(space, ":");
     }   
 
@@ -1104,10 +1404,10 @@ BOOL MakeMount(const CString& strDir, const CString& strVolName, const CString&
     blob.in_size = 1 + strlen(space);
     blob.in = space;
     blob.out = NULL;
-    code = pioctl(PCCHAR(strDir), VIOC_AFS_CREATE_MT_PT, &blob, 0);
+    code = pioctl(path, VIOC_AFS_CREATE_MT_PT, &blob, 0);
 
     if (code) {
-        ShowMessageBox(IDS_MOUNT_POINT_ERROR, MB_ICONEXCLAMATION, IDS_MOUNT_POINT_ERROR, GetAfsError(errno, strDir));
+        ShowMessageBox(IDS_MOUNT_POINT_ERROR, MB_ICONERROR, IDS_MOUNT_POINT_ERROR, GetAfsError(errno, strDir));
         return FALSE;
     }
     
@@ -1165,6 +1465,19 @@ BOOL RemoveSymlink(const char * linkName)
         strncpy(tbuffer, linkName, code=tp-linkName+1);  /* the dir name */
         tbuffer[code] = 0;
         tp++;   /* skip the slash */
+
+	if (!IsPathInAfs(tbuffer)) {
+	    const char * nbname = NetbiosName();
+	    int len = strlen(nbname);
+
+	    if (tbuffer[0] == '\\' && tbuffer[1] == '\\' &&
+		 tbuffer[len+2] == '\\' &&
+		 tbuffer[len+3] == '\0' &&
+		 !strnicmp(nbname,&tbuffer[2],len))
+	    {
+		sprintf(tbuffer,"\\\\%s\\all\\", nbname);
+	    }
+	}
     }
     else {
         fs_ExtractDriveLetter(linkName, tbuffer);
@@ -1172,6 +1485,12 @@ BOOL RemoveSymlink(const char * linkName)
         fs_StripDriveLetter(tp, tpbuffer, 0);
         tp=tpbuffer;
     }
+
+    if ( IsFreelanceRoot(tbuffer) && !IsAdmin() ) {
+	ShowMessageBox(IDS_NOT_AFS_CLIENT_ADMIN_ERROR, MB_ICONERROR, IDS_NOT_AFS_CLIENT_ADMIN_ERROR);
+	return FALSE;
+    }
+
     blob.in = tp;
     blob.in_size = strlen(tp)+1;
     blob.out = lsbuffer;
@@ -1206,6 +1525,19 @@ BOOL IsSymlink(const char * true_name)
         strncpy(parent_dir, true_name, last_component - true_name + 1);
         parent_dir[last_component - true_name + 1] = 0;
         last_component++;   /*Skip the slash*/
+
+	if (!IsPathInAfs(parent_dir)) {
+	    const char * nbname = NetbiosName();
+	    int len = strlen(nbname);
+
+	    if (parent_dir[0] == '\\' && parent_dir[1] == '\\' &&
+		 parent_dir[len+2] == '\\' &&
+		 parent_dir[len+3] == '\0' &&
+		 !strnicmp(nbname,&parent_dir[2],len))
+	    {
+		sprintf(parent_dir,"\\\\%s\\all\\", nbname);
+	    }
+	}
     }
     else {
         /*
@@ -1244,6 +1576,19 @@ BOOL IsMountPoint(const char * name)
         strncpy(tbuffer, szCurItem, code = tp - szCurItem + 1);  /* the dir name */
         tbuffer[code] = 0;
         tp++;   /* skip the slash */
+
+	if (!IsPathInAfs(tbuffer)) {
+	    const char * nbname = NetbiosName();
+	    int len = strlen(nbname);
+
+	    if (tbuffer[0] == '\\' && tbuffer[1] == '\\' &&
+		 tbuffer[len+2] == '\\' &&
+		 tbuffer[len+3] == '\0' &&
+		 !strnicmp(nbname,&tbuffer[2],len))
+	    {
+		sprintf(tbuffer,"\\\\%s\\all\\", nbname);
+	    }
+	}
     } else {
         fs_ExtractDriveLetter(szCurItem, tbuffer);
         strcat(tbuffer, ".");
@@ -1273,7 +1618,6 @@ BOOL RemoveMount(CStringArray& files)
     register LONG code = 0;
     struct ViceIoctl blob;
     char tbuffer[1024];
-    char lsbuffer[1024];
     register char *tp;
     char szCurItem[1024];
     BOOL error = FALSE;
@@ -1300,6 +1644,19 @@ BOOL RemoveMount(CStringArray& files)
             strncpy(tbuffer, szCurItem, code = tp - szCurItem + 1);  /* the dir name */
             tbuffer[code] = 0;
             tp++;   /* skip the slash */
+
+	    if (!IsPathInAfs(tbuffer)) {
+		const char * nbname = NetbiosName();
+		int len = strlen(nbname);
+
+		if (tbuffer[0] == '\\' && tbuffer[1] == '\\' &&
+		    tbuffer[len+2] == '\\' &&
+		    tbuffer[len+3] == '\0' &&
+		    !strnicmp(nbname,&tbuffer[2],len))
+		{
+		    sprintf(tbuffer,"\\\\%s\\all\\", nbname);
+		}
+	    }
         } else {
             fs_ExtractDriveLetter(szCurItem, tbuffer);
             strcat(tbuffer, ".");
@@ -1307,6 +1664,12 @@ BOOL RemoveMount(CStringArray& files)
             fs_StripDriveLetter(tp, tp, 0);
         }
 
+	if ( IsFreelanceRoot(tbuffer) && !IsAdmin() ) {
+	    results.Add(GetMessageString(IDS_NOT_AFS_CLIENT_ADMIN_ERROR, StripPath(files[i])));
+            error = TRUE;
+            continue;   /* skip */
+        }
+
         blob.out_size = 0;
         blob.in = tp;
         blob.in_size = strlen(tp)+1;
@@ -1417,7 +1780,7 @@ BOOL SetVolInfo(CVolInfo& volInfo)
 
     code = pioctl(PCCHAR(volInfo.m_strFilePath), VIOCSETVOLSTAT, &blob, 1);
     if (code) {
-        ShowMessageBox(IDS_SET_QUOTA_ERROR, MB_ICONEXCLAMATION, IDS_SET_QUOTA_ERROR, GetAfsError(errno, volInfo.m_strName));
+        ShowMessageBox(IDS_SET_QUOTA_ERROR, MB_ICONERROR, IDS_SET_QUOTA_ERROR, GetAfsError(errno, volInfo.m_strName));
         return FALSE;
     }
 
@@ -1447,42 +1810,36 @@ BOOL CheckServers(const CString& strCellName, WHICH_CELLS nCellsToCheck, BOOL bF
 
     blob.out_size = MAXSIZE;
     blob.out = space;
-    memset(space, 0, sizeof(LONG));	/* so we assure zero when nothing is copied back */
-
-    /* prepare flags for checkservers command */
-    if (nCellsToCheck == LOCAL_CELL)
-        temp = 2;	/* default to checking local cell only */
-    else if (nCellsToCheck == ALL_CELLS)
-        temp &= ~2;	/* turn off local cell check */
+    memset(space, 0, sizeof(afs_int32));	/* so we assure zero when nothing is copied back */
 
+    if (nCellsToCheck == SPECIFIC_CELL) {
+	temp = 2;
+        GetCellName(PCCHAR(strCellName), &info);
+        strcpy(checkserv.tbuffer,info.name);
+        checkserv.tsize = strlen(info.name) + 1;
+    } else {
+	if (nCellsToCheck != ALL_CELLS)
+	    temp = 2;
+        strcpy(checkserv.tbuffer, "\0");
+        checkserv.tsize = 0;
+    }
     if (bFast)
         temp |= 1;	/* set fast flag */
     
     checkserv.magic = 0x12345678;	/* XXX */
     checkserv.tflags = temp;
-
-    /* now copy in optional cell name, if specified */
-    if (nCellsToCheck == SPECIFIC_CELL) {
-        GetCellName(PCCHAR(strCellName), &info);
-        strcpy(checkserv.tbuffer,info.name);
-        checkserv.tsize = strlen(info.name) + 1;
-    } else {
-        strcpy(checkserv.tbuffer, "\0");
-        checkserv.tsize = 0;
-    }
-
     checkserv.tinterval = -1;	/* don't change current interval */
 
     code = pioctl(0, VIOCCKSERV, &blob, 1);
     if (code) {
-        ShowMessageBox(IDS_CHECK_SERVERS_ERROR, MB_ICONEXCLAMATION, IDS_CHECK_SERVERS_ERROR, GetAfsError(errno, CString()));
+        ShowMessageBox(IDS_CHECK_SERVERS_ERROR, MB_ICONERROR, IDS_CHECK_SERVERS_ERROR, GetAfsError(errno, CString()));
         return FALSE;
     }
 
     memcpy(&temp, space, sizeof(LONG));
 
     if (temp == 0) {
-        ShowMessageBox(IDS_ALL_SERVERS_RUNNING, MB_OK, IDS_ALL_SERVERS_RUNNING);
+        ShowMessageBox(IDS_ALL_SERVERS_RUNNING, MB_OK|MB_ICONINFORMATION, IDS_ALL_SERVERS_RUNNING);
         return TRUE;
     }
 
@@ -1543,7 +1900,7 @@ BOOL GetTokenInfo(CStringArray& tokenInfo)
             break;
         }
         else if (rc) {
-            ShowMessageBox(IDS_GET_TOKENS_UNEXPECTED_ERROR, MB_ICONEXCLAMATION, IDS_GET_TOKENS_UNEXPECTED_ERROR, rc);
+            ShowMessageBox(IDS_GET_TOKENS_UNEXPECTED_ERROR, MB_ICONERROR, IDS_GET_TOKENS_UNEXPECTED_ERROR, rc);
             return FALSE;
 //	    printf("Unexpected error, code %d\n", rc);
 //	    exit(1);
@@ -1551,7 +1908,7 @@ BOOL GetTokenInfo(CStringArray& tokenInfo)
         else {
             rc = ktc_GetToken(&serviceName, &token, sizeof(token), &clientName);
             if (rc) {
-                ShowMessageBox(IDS_GET_TOKENS_UNEXPECTED_ERROR2, MB_ICONEXCLAMATION, IDS_GET_TOKENS_UNEXPECTED_ERROR2, 
+                ShowMessageBox(IDS_GET_TOKENS_UNEXPECTED_ERROR2, MB_ICONERROR, IDS_GET_TOKENS_UNEXPECTED_ERROR2, 
                                 serviceName.name, serviceName.instance,	serviceName.cell, rc);
                 continue;
             }
@@ -1602,17 +1959,53 @@ BOOL GetTokenInfo(CStringArray& tokenInfo)
     return TRUE;
 }
 
-UINT MakeSymbolicLink(const char *strName ,const char *strDir)
+UINT MakeSymbolicLink(const char *strName, const char *strDir)
 {
     struct ViceIoctl blob;
     char space[MAXSIZE];
+    char * parent;
+    char path[1024] = "";
     UINT code;
 
     HOURGLASS hourglass;
+    static char message[2048];
+
+    strcpy(path, strDir);
+    parent = Parent(path);
+
+    sprintf(message,"MakeSymbolicLink: path = %s parent = %s\n",path,parent);
+    OutputDebugString(message);
 
     /*lets confirm its a good symlink*/
-    if (!IsPathInAfs(strDir))
-        return 1;
+    if (!IsPathInAfs(path)) {
+	const char * nbname = NetbiosName();
+	int len = strlen(nbname);
+
+	if (parent[0] == '\\' && parent[1] == '\\' &&
+	    parent[len+2] == '\\' &&
+	    parent[len+3] == '\0' &&
+	    !strnicmp(nbname,&parent[2],len))
+	{
+	    sprintf(path,"%sall\\%s", parent, &strDir[strlen(parent)]);
+	    parent = Parent(path);
+	    sprintf(message,"MakeSymbolicLink: new path = %s parent = %s\n",path,parent);
+	    OutputDebugString(message);
+
+	    if (!IsPathInAfs(parent)) {
+		ShowMessageBox(IDS_MAKE_LNK_NOT_AFS_ERROR, MB_ICONERROR, IDS_MAKE_LNK_NOT_AFS_ERROR);
+		return TRUE;
+	    }
+	} else {
+	    ShowMessageBox(IDS_MAKE_LNK_NOT_AFS_ERROR, MB_ICONERROR, IDS_MAKE_LNK_NOT_AFS_ERROR);
+	    return TRUE;
+	}
+    }
+
+    if ( IsFreelanceRoot(parent) && !IsAdmin() ) {
+	ShowMessageBox(IDS_NOT_AFS_CLIENT_ADMIN_ERROR, MB_ICONERROR, IDS_NOT_AFS_CLIENT_ADMIN_ERROR);
+	return FALSE;
+    }
+
     LPTSTR lpsz = new TCHAR[strlen(strDir)+1];
     _tcscpy(lpsz, strName);
     strcpy(space, strDir);
@@ -1620,9 +2013,11 @@ UINT MakeSymbolicLink(const char *strName ,const char *strDir)
     blob.in_size = 1 + strlen(space);
     blob.in = space;
     blob.out = NULL;
-    if ((code=pioctl(lpsz, VIOC_SYMLINK, &blob, 0))!=0)
+    code=pioctl(lpsz, VIOC_SYMLINK, &blob, 0);
+    delete lpsz;
+    if (code != 0)
         return code;
-    return 0;
+    return FALSE;
 }
 
 void ListSymbolicLinkPath(const char *strName,char *strPath,UINT nlenPath)
@@ -1639,20 +2034,33 @@ void ListSymbolicLinkPath(const char *strName,char *strPath,UINT nlenPath)
 
     strcpy(orig_name, strName);
     strcpy(true_name, orig_name);
-	/*
-	 * Find rightmost slash, if any.
-	 */
+    /*
+     * Find rightmost slash, if any.
+     */
     last_component = (char *) strrchr(true_name, '\\');
     if (!last_component)
         last_component = (char *) strrchr(true_name, '/');
     if (last_component) {
-	    /*
-	     * Found it.  Designate everything before it as the parent directory,
-	     * everything after it as the final component.
-	     */
+	/*
+	 * Found it.  Designate everything before it as the parent directory,
+	 * everything after it as the final component.
+	 */
         strncpy(parent_dir, true_name, last_component - true_name + 1);
         parent_dir[last_component - true_name + 1] = 0;
         last_component++;   /*Skip the slash*/
+
+	if (!IsPathInAfs(parent_dir)) {
+	    const char * nbname = NetbiosName();
+	    int len = strlen(nbname);
+
+	    if (parent_dir[0] == '\\' && parent_dir[1] == '\\' &&
+		 parent_dir[len+2] == '\\' &&
+		 parent_dir[len+3] == '\0' &&
+		 !strnicmp(nbname,&parent_dir[2],len))
+	    {
+		sprintf(parent_dir,"\\\\%s\\all\\", nbname);
+	    }
+	}
     }
     else {
         /*
