@@ -54,7 +54,7 @@ osi_fdOps_t osi_logFDOps = {
 };
 
 /* create a new log, taking a name and a size in entries (not words) */
-osi_log_t *osi_LogCreate(char *namep, long size)
+osi_log_t *osi_LogCreate(char *namep, size_t size)
 {
 	osi_log_t *logp;
         osi_fdType_t *typep;
@@ -253,7 +253,7 @@ void osi_LogPrint(osi_log_t *logp, FILE_HANDLE handle)
 			lep->parms[0], lep->parms[1],
 			lep->parms[2], lep->parms[3]);
 		snprintf(wholemsg, sizeof(wholemsg),
-			 "time %d.%06d, tid %d %s\n",
+			 "time %d.%06d, tid %d %s\r\n",
 			lep->micros / 1000000,
 			lep->micros % 1000000,
 			lep->tid, msg);
