@@ -22,7 +22,7 @@
  * SOFTWARE.
  */
 
-/* $Id: afsfuncs.c,v 1.1.2.6 2007/03/31 12:53:49 jaltman Exp $ */
+/* $Id: afsfuncs.c,v 1.1.2.8 2007/04/10 22:09:18 jaltman Exp $ */
 
 /* Disable the 'macro redefinition' warning which is getting
    triggerred by a redefinition of the ENCRYPT and DECRYPT macros. */
@@ -472,7 +472,7 @@ _no_krb5:
 
            ASSUMPTION:
 
-           If Krb5 was used to obatain the token, then there is a Krb5
+           If Krb5 was used to obtain the token, then there is a Krb5
            ticket of the form afs/<cell>@<REALM> or afs@<CELL> still
            in the cache.  This is also true for Krb524 token
            acquisition.
@@ -630,9 +630,7 @@ ViceIDToUsername(char *username,
 {
     static char lastcell[MAXCELLCHARS+1] = { 0 };
     static char confname[512] = { 0 };
-#ifdef AFS_ID_TO_NAME
     char username_copy[BUFSIZ];
-#endif /* AFS_ID_TO_NAME */
     long viceId = ANONYMOUSID;		/* AFS uid of user */
     int  status = 0;
 #ifdef ALLOW_REGISTER
@@ -667,18 +665,20 @@ ViceIDToUsername(char *username,
      * automatically register with the ptserver in foreign cells
      */
 
+    /* copy the username because pr_CreateUser will lowercase it */
+    StringCbCopyA(username_copy, BUFSIZ, username);
+
 #ifdef ALLOW_REGISTER
     if (status == 0) {
         if (viceId != ANONYMOUSID) {
 #else /* ALLOW_REGISTER */
 	    if ((status == 0) && (viceId != ANONYMOUSID))
 #endif /* ALLOW_REGISTER */
-    {
+            {
 #ifdef AFS_ID_TO_NAME
-	StringCbCopyA(username_copy, BUFSIZ, username);
-	StringCchPrintfA(username, BUFSIZ, "%s (AFS ID %d)", username_copy, (int) viceId);
+                StringCchPrintfA(username, BUFSIZ, "%s (AFS ID %d)", username_copy, (int) viceId);
 #endif /* AFS_ID_TO_NAME */
-    }
+            }
 #ifdef ALLOW_REGISTER
         } else if (strcmp(realm_of_user, realm_of_cell) != 0) {
             id = 0;
@@ -691,10 +691,10 @@ ViceIDToUsername(char *username,
                 return status;
             status = pr_CreateUser(username, &id);
 	    pr_End();
+            StringCbCopyA(username, BUFSIZ, username_copy);
 	    if (status)
 		return status;
 #ifdef AFS_ID_TO_NAME
-            StringCbCopyA(username_copy, BUFSIZ, username);
             StringCchPrintfA(username, BUFSIZ, "%s (AFS ID %d)", username_copy, (int) viceId);
 #endif /* AFS_ID_TO_NAME */
         }
@@ -729,6 +729,7 @@ afs_klog(khm_handle identity,
     char	ServiceName[128];
     khm_handle	confighandle;
     khm_int32	supports_krb4 = 1;
+    khm_int32   got524cred = 0;
 
     /* signalling */
     BOOL        bGotCreds = FALSE; /* got creds? */
@@ -1017,6 +1018,7 @@ afs_klog(khm_handle identity,
                 goto end_krb5;
             }
             rc = KSUCCESS;
+	    got524cred = 1;
             bGotCreds = TRUE;
         }
 
@@ -1146,7 +1148,7 @@ afs_klog(khm_handle identity,
         StringCbCopyA(aclient.instance, sizeof(aclient.instance), "");
 
         StringCchCatA(aclient.name, MAXKTCNAMELEN, "@");
-        StringCchCatA(aclient.name, MAXKTCNAMELEN, creds.realm);
+		StringCchCatA(aclient.name, MAXKTCNAMELEN, got524cred ? realm_of_user : creds.realm);
 
         StringCbCopyA(aclient.cell, sizeof(aclient.cell), CellName);
 
