@@ -31,8 +31,6 @@
 #define osi_Time()	time_second
 #define	afs_hz		hz
 
-#define PAGESIZE 8192
-
 #define	AFS_UCRED	ucred
 #define	AFS_PROC	struct proc
 
@@ -121,4 +119,6 @@ extern struct proc *afs_global_owner;
 #define USERPRI splx(splvar)
 #endif /* KERNEL */
 
+#define ifnet_flags(x) (x?(x)->if_flags:0)
+
 #endif /* _OSI_MACHDEP_H_ */
