@@ -59,7 +59,9 @@
 #include "afsincludes.h"
 #endif
 #include <linux/version.h>
+#ifdef CONFIG_H_EXISTS
 #include <linux/config.h>
+#endif
 #include <linux/linkage.h>
 #include <linux/init.h>
 #include <linux/unistd.h>
@@ -231,7 +233,9 @@ extern SYSCALLTYPE sys_call_table_emu[] __attribute__((weak));
 
 extern asmlinkage ssize_t sys_read(unsigned int fd, char __user * buf, size_t count) __attribute__((weak));
 extern asmlinkage long sys_close(unsigned int) __attribute__((weak));
+#if defined(EXPORTED_SYS_CHDIR)
 extern asmlinkage long sys_chdir(const char *) __attribute__((weak));
+#endif
 extern asmlinkage ssize_t sys_write(unsigned int, const char *, size_t) __attribute__((weak));
 #ifdef AFS_LINUX26_ENV
 extern asmlinkage long sys_wait4(pid_t, int *, int, struct rusage *) __attribute__((weak));
@@ -239,7 +243,9 @@ extern asmlinkage long sys_wait4(pid_t, int *, int, struct rusage *) __attribute
 extern asmlinkage long sys_wait4(pid_t, unsigned int *, int, struct rusage *) __attribute__((weak));
 #endif
 extern asmlinkage long sys_exit (int) __attribute__((weak));
+#if defined(EXPORTED_SYS_OPEN)
 extern asmlinkage long sys_open (const char *, int, int) __attribute__((weak));
+#endif
 extern asmlinkage long sys_ioctl(unsigned int, unsigned int, unsigned long) __attribute__((weak));
 
 
@@ -300,14 +306,20 @@ typedef struct {
 /* On PPC64 and SPARC64, we need to omit the ones that might match both tables */
 static tryctl main_try[] = {
 #if !defined(AFS_PPC64_LINUX20_ENV) && !defined(AFS_SPARC64_LINUX20_ENV)
+#if defined(EXPORTED_SYS_CHDIR)
     { "scan: close+chdir+write", __NR_close, &sys_close, __NR_chdir, &sys_chdir, __NR_write, &sys_write },
+#endif
 #endif
     { "scan: close+wait4",       __NR_close, &sys_close, __NR_wait4, &sys_wait4, -1,         0          },
 #if !defined(AFS_PPC64_LINUX20_ENV) && !defined(AFS_SPARC64_LINUX20_ENV)
+#if defined(EXPORTED_SYS_CHDIR)
     { "scan: close+chdir",       __NR_close, &sys_close, __NR_chdir, &sys_chdir, -1,         0          },
+#endif
 #endif
     { "scan: close+ioctl",       __NR_close, &sys_close, __NR_ioctl, &sys_ioctl, -1,         0          },
+#if defined(EXPORTED_SYS_OPEN)
     { "scan: exit+open",         __NR_exit,  &sys_exit,  __NR_open,  &sys_open,  -1,         0          },
+#endif
     { 0 }
 };
 
@@ -502,7 +514,7 @@ static probectl main_probe = {
     (unsigned long)&sys_close,
 #elif defined(AFS_AMD64_LINUX20_ENV)
     /* On this platform, it's in a different section! */
-    (unsigned long)&tasklist_lock,
+    (unsigned long)&generic_ro_fops,
 #else
     (unsigned long)&init_mm,
 #endif
@@ -524,7 +536,7 @@ static probectl main_probe = {
     0x1fffff,
     0x30000,
 #elif defined(AFS_AMD64_LINUX20_ENV)
-    (unsigned long)(&tasklist_lock) - 0x30000,
+    (unsigned long)(&generic_ro_fops) - 0x30000,
     0,
     0x6000,
 #elif defined(AFS_PPC64_LINUX26_ENV)
@@ -543,9 +555,9 @@ static probectl main_probe = {
 
 #ifdef AFS_LINUX26_ENV
     (unsigned long)scsi_command_size,
-    (unsigned long)scsi_command_size,
+    (unsigned long)scsi_command_size - 0x10000,
     0x3ffff,
-    0x30000,
+    0x40000,
 #else
     0, 0, 0, 0,
 #endif
@@ -590,8 +602,10 @@ static probectl main_probe = {
 
 /* syscall pairs/triplets to probe */
 static tryctl ia32_try[] = {
+#if defined(EXPORTED_SYS_CHDIR)
     { "scan: close+chdir+write", __NR_ia32_close, &sys_close, __NR_ia32_chdir, &sys_chdir,        __NR_ia32_write, &sys_write },
     { "scan: close+chdir",       __NR_ia32_close, &sys_close, __NR_ia32_chdir, &sys_chdir,        -1,              0          },
+#endif
     { 0 }
 };
 
@@ -639,9 +653,9 @@ static probectl ia32_probe = {
 
 #ifdef AFS_LINUX26_ENV
     (unsigned long)scsi_command_size,
-    (unsigned long)scsi_command_size,
+    (unsigned long)scsi_command_size - 0x10000,
     0x3ffff,
-    0x30000,
+    0x40000,
 #else
     0, 0, 0, 0,
 #endif
@@ -778,9 +792,9 @@ static probectl sct32_probe = {
 
 #ifdef AFS_LINUX26_ENV
     (unsigned long)scsi_command_size,
-    (unsigned long)scsi_command_size,
+    (unsigned long)scsi_command_size - 0x10000,
     0x3ffff,
-    0x30000,
+    0x40000,
 #else
     0, 0, 0, 0,
 #endif
@@ -873,9 +887,9 @@ static probectl emu_probe = {
 
 #ifdef AFS_LINUX26_ENV
     (unsigned long)scsi_command_size,
-    (unsigned long)scsi_command_size,
+    (unsigned long)scsi_command_size - 0x10000,
     0x3ffff,
-    0x30000,
+    0x40000,
 #else
     0, 0, 0, 0,
 #endif
@@ -996,6 +1010,17 @@ static void *try(probectl *P, tryctl *T, PROBETYPE *aptr,
 #else
 	ptr = aptr;
 #endif
+	if ((unsigned long)ptr < init_mm.start_code ||
+#if defined(AFS_AMD64_LINUX20_ENV)
+		(unsigned long)ptr > init_mm.brk)
+#else
+		(unsigned long)ptr > init_mm.end_data)
+#endif
+	{
+/*	     printk("address 0x%lx (from 0x%lx %d) is out of range in check_table. wtf?\n", (unsigned long)x, (unsigned long)ptr, i);*/
+	     continue;
+	}
+
 	ret = check_table(P, ptr);
 	if (ret >= 0) {
 	    /* return value is number of entries to skip */
@@ -1100,6 +1125,16 @@ static void *try_harder(probectl *P, PROBETYPE *ptr, unsigned long datalen)
 	printk("<7>osi_probe: %s                      try_harder\n", P->symbol);
 #endif
     for (offset = 0; offset < datalen; offset++, ptr++) {
+	 if ((unsigned long)ptr < init_mm.start_code ||
+#if defined(AFS_AMD64_LINUX20_ENV)
+		(unsigned long)ptr > init_mm.brk)
+#else
+		(unsigned long)ptr > init_mm.end_data)
+#endif
+	{
+/*	     printk("address 0x%lx (from 0x%lx %d) is out of range in check_table. wtf?\n", (unsigned long)x, (unsigned long)ptr, i);*/
+	     continue;
+	}
 	ret = check_table(P, ptr);
         if (ret >= 0) {
             /* return value is number of entries to skip */
