@@ -1,7 +1,7 @@
 /*
  * osi_sysctl.c: Linux sysctl interface to OpenAFS
  *
- * $Id: osi_sysctl.c,v 1.7.2.1 2005/05/08 05:04:14 shadow Exp $
+ * $Id: osi_sysctl.c,v 1.9.2.2 2007/02/22 21:47:26 shadow Exp $
  *
  * Written Jan 30, 2002 by Kris Van Hees (Sine Nomine Associates)
  */
@@ -14,7 +14,12 @@
 #include "afs/afs_stats.h"	/* afs statistics */
 
 #include <linux/sysctl.h>
+#ifdef CONFIG_H_EXISTS
 #include <linux/config.h>
+#endif
+
+/* From afs_util.c */
+extern afs_int32 afs_new_inum;
 
 /* From afs_analyze.c */
 extern afs_int32 hm_retry_RO;
@@ -82,6 +87,10 @@ static ctl_table afs_sysctl_table[] = {
      &afs_cacheBlocks, sizeof(afs_int32), 0644, NULL,
      &proc_dointvec}
     ,
+    {7, "md5inum",
+     &afs_new_inum, sizeof(afs_int32), 0644, NULL,
+     &proc_dointvec}
+    ,
     {0}
 };
 
@@ -93,7 +102,11 @@ static ctl_table fs_sysctl_table[] = {
 int
 osi_sysctl_init()
 {
+#if defined(REGISTER_SYSCTL_TABLE_NOFLAG)
+    afs_sysctl = register_sysctl_table(fs_sysctl_table);
+#else
     afs_sysctl = register_sysctl_table(fs_sysctl_table, 0);
+#endif
     if (!afs_sysctl)
 	return -1;
 
