@@ -23,7 +23,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_readdir.c,v 1.24.2.2 2004/10/18 17:43:53 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_readdir.c,v 1.33 2005/11/19 04:33:00 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -67,7 +67,7 @@ extern struct DirEntry *afs_dir_GetBlob();
     become static.
 */
 int
-BlobScan(struct fcache * afile, afs_int32 ablob)
+BlobScan(struct dcache * afile, afs_int32 ablob)
 {
     register afs_int32 relativeBlob;
     afs_int32 pageBlob;
@@ -143,28 +143,30 @@ struct irix5_min_dirent {	/* miniature dirent structure */
 #else
 struct min_direct {		/* miniature direct structure */
     /* If struct direct changes, this must too */
-#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
+#if defined(AFS_DARWIN80_ENV)
+    ino_t d_fileno;
+    u_short d_reclen;
+    u_char d_type;
+    u_char d_namlen;
+#elif defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     afs_uint32 d_fileno;
     u_short d_reclen;
     u_char d_type;
     u_char d_namlen;
-#else
-#ifdef	AFS_SUN5_ENV
+#elif defined(AFS_SUN5_ENV)
     afs_uint32 d_fileno;
     afs_int32 d_off;
     u_short d_reclen;
 #else
-#if defined(AFS_SUN_ENV) || defined(AFS_AIX32_ENV)
+#if defined(AFS_AIX32_ENV)
     afs_int32 d_off;
-#endif
-#if     defined(AFS_HPUX100_ENV)
+#elif defined(AFS_HPUX100_ENV)
     unsigned long long d_off;
 #endif
     afs_uint32 d_fileno;
     u_short d_reclen;
     u_short d_namlen;
 #endif
-#endif
 };
 #endif /* AFS_SGI_ENV */
 
@@ -245,7 +247,10 @@ afs_readdir_type(avc, ade)
     tfid.Fid.Unique = ntohl(ade->fid.vunique);
     if ((avc->states & CForeign) == 0 && (ntohl(ade->fid.vnode) & 1)) {
 	return DT_DIR;
-    } else if ((tvc = afs_FindVCache(&tfid, 0, 0))) {
+    }
+    ObtainReadLock(&afs_xvcache);
+    if ((tvc = afs_FindVCache(&tfid, 0, 0))) {
+        ReleaseReadLock(&afs_xvcache);
 	if (tvc->mvstat) {
 	    afs_PutVCache(tvc);
 	    return DT_DIR;
@@ -264,7 +269,8 @@ afs_readdir_type(avc, ade)
 	    /* what other types does AFS support? */
 	} else
 	    afs_PutVCache(tvc);
-    }
+    } else
+        ReleaseReadLock(&afs_xvcache);
     return DT_UNKNOWN;
 }
 #endif
@@ -292,6 +298,9 @@ afs_readdir_move(de, vc, auio, slen, rlen, off)
      afs_size_t off;
 {
     int code = 0;
+    struct volume *tvp;
+    afs_uint32 Volume = vc->fid.Fid.Volume;
+    afs_uint32 Vnode  = de->fid.vnode;
 #if	defined(AFS_SUN56_ENV)
     struct dirent64 *direntp;
 #else
@@ -304,6 +313,79 @@ afs_readdir_move(de, vc, auio, slen, rlen, off)
 #endif /* AFS_SGI53_ENV */
 
     AFS_STATCNT(afs_readdir_move);
+
+#define READDIR_CORRECT_INUMS
+#ifdef READDIR_CORRECT_INUMS
+    if (de->name[0] == '.' && !de->name[1]) {
+	/* This is the '.' entry; if we are a volume root, we need to
+	 * ignore the directory and use the inum for the mount point.
+	 */
+	if (!FidCmp(&afs_rootFid, &vc->fid)) {
+	    Volume = 0;
+	    Vnode  = 2;
+	} else if (vc->mvstat == 2) {
+	    tvp = afs_GetVolume(&vc->fid, 0, READ_LOCK);
+	    if (tvp) {
+		Volume = tvp->mtpoint.Fid.Volume;
+		Vnode  = tvp->mtpoint.Fid.Vnode;
+		afs_PutVolume(tvp, READ_LOCK);
+	    }
+	}
+    }
+    else if (de->name[0] == '.' && de->name[1] == '.' && !de->name[2]) {
+	/* This is the '..' entry.  Getting this right is very tricky,
+	 * because we might be a volume root (so our parent is in a
+	 * different volume), or our parent might be a volume root
+	 * (so we actually want the mount point) or BOTH! */
+	if (!FidCmp(&afs_rootFid, &vc->fid)) {
+	    /* We are the root of the AFS root, and thus our own parent */
+	    Volume = 0;
+	    Vnode  = 2;
+	} else if (vc->mvstat == 2) {
+	    /* We are a volume root, which means our parent is in another
+	     * volume.  Luckily, we should have his fid cached... */
+	    if (vc->mvid) {
+		if (!FidCmp(&afs_rootFid, vc->mvid)) {
+		    /* Parent directory is the root of the AFS root */
+		    Volume = 0;
+		    Vnode  = 2;
+		} else if (vc->mvid->Fid.Vnode == 1
+			   && vc->mvid->Fid.Unique == 1) {
+		    /* XXX The above test is evil and probably breaks DFS */
+		    /* Parent directory is the target of a mount point */
+		    tvp = afs_GetVolume(vc->mvid, 0, READ_LOCK);
+		    if (tvp) {
+			Volume = tvp->mtpoint.Fid.Volume;
+			Vnode  = tvp->mtpoint.Fid.Vnode;
+			afs_PutVolume(tvp, READ_LOCK);
+		    }
+		} else {
+		    /* Parent directory is not a volume root */
+		    Volume = vc->mvid->Fid.Volume;
+		    Vnode  = vc->mvid->Fid.Vnode;
+		}
+	    }
+	} else if (de->fid.vnode == 1 && de->fid.vunique == 1) {
+	    /* XXX The above test is evil and probably breaks DFS */
+	    /* Parent directory is a volume root; use the right inum */
+	    tvp = afs_GetVolume(&vc->fid, 0, READ_LOCK);
+	    if (tvp) {
+		if (tvp->cell == afs_rootFid.Cell
+		    && tvp->volume == afs_rootFid.Fid.Volume) {
+		    /* Parent directory is the root of the AFS root */
+		    Volume = 0;
+		    Vnode  = 2;
+		} else {
+		    /* Parent directory is the target of a mount point */
+		    Volume = tvp->mtpoint.Fid.Volume;
+		    Vnode  = tvp->mtpoint.Fid.Vnode;
+		}
+		afs_PutVolume(tvp, READ_LOCK);
+	    }
+	}
+    }
+#endif
+
 #ifdef	AFS_SGI53_ENV
     {
 	afs_int32 use64BitDirent;
@@ -328,8 +410,7 @@ afs_readdir_move(de, vc, auio, slen, rlen, off)
 
 	if (use64BitDirent) {
 	    struct min_dirent sdirEntry;
-	    sdirEntry.d_fileno =
-		(vc->fid.Fid.Volume << 16) + ntohl(de->fid.vnode);
+	    sdirEntry.d_fileno = (Volume << 16) + ntohl(Vnode);
 	    FIXUPSTUPIDINODE(sdirEntry.d_fileno);
 	    sdirEntry.d_reclen = rlen;
 	    sdirEntry.d_off = (off_t) off;
@@ -352,8 +433,7 @@ afs_readdir_move(de, vc, auio, slen, rlen, off)
 	    }
 	} else {
 	    struct irix5_min_dirent sdirEntry;
-	    sdirEntry.d_fileno =
-		(vc->fid.Fid.Volume << 16) + ntohl(de->fid.vnode);
+	    sdirEntry.d_fileno = (Volume << 16) + ntohl(Vnode);
 	    FIXUPSTUPIDINODE(sdirEntry.d_fileno);
 	    sdirEntry.d_reclen = rlen;
 	    sdirEntry.d_off = (afs_int32) off;
@@ -384,7 +464,7 @@ afs_readdir_move(de, vc, auio, slen, rlen, off)
 #else
     direntp = (struct dirent *)osi_AllocLargeSpace(AFS_LRALLOCSIZ);
 #endif
-    direntp->d_ino = (vc->fid.Fid.Volume << 16) + ntohl(de->fid.vnode);
+    direntp->d_ino =  (Volume << 16) + ntohl(Vnode);
     FIXUPSTUPIDINODE(direntp->d_ino);
 #if defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL)
     direntp->d_offset = off;
@@ -398,13 +478,13 @@ afs_readdir_move(de, vc, auio, slen, rlen, off)
     osi_FreeLargeSpace((char *)direntp);
 #else /* AFS_SUN5_ENV */
     /* Note the odd mechanism for building the inode number */
-    sdirEntry.d_fileno = (vc->fid.Fid.Volume << 16) + ntohl(de->fid.vnode);
+    sdirEntry.d_fileno = (Volume << 16) + ntohl(Vnode);
     FIXUPSTUPIDINODE(sdirEntry.d_fileno);
     sdirEntry.d_reclen = rlen;
 #if !defined(AFS_SGI_ENV)
     sdirEntry.d_namlen = slen;
 #endif
-#if defined(AFS_SUN_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_SGI_ENV)
+#if defined(AFS_AIX32_ENV) || defined(AFS_SGI_ENV)
     sdirEntry.d_off = off;
 #endif
 #if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
@@ -509,8 +589,9 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #if defined(AFS_SGI53_ENV)
     afs_int32 use64BitDirent, dirsiz;
 #endif /* defined(AFS_SGI53_ENV) */
+#ifndef	AFS_HPUX_ENV
     OSI_VC_CONVERT(avc);
-#ifdef	AFS_HPUX_ENV
+#else
     /*
      * XXX All the hacks for alloced sdirEntry and inlining of afs_readdir_move instead of calling
      * it is necessary for hpux due to stack problems that seem to occur when coming thru the nfs
@@ -553,9 +634,11 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
     if (eofp)
 	*eofp = 0;
 #endif
+#ifndef AFS_64BIT_CLIENT
     if (AfsLargeFileUio(auio)	/* file is large than 2 GB */
-	||AfsLargeFileSize(auio->uio_offset, auio->uio_resid))
+	||AfsLargeFileSize(AFS_UIO_OFFSET(auio), AFS_UIO_RESID(auio)))
 	return EFBIG;
+#endif
 
     if ((code = afs_InitReq(&treq, acred))) {
 #ifdef	AFS_HPUX_ENV
@@ -638,11 +721,11 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
     auio->uio_fpflags = 0;
 #endif
     while (code == 0) {
-	origOffset = auio->afsio_offset;
+	origOffset = AFS_UIO_OFFSET(auio);
 	/* scan for the next interesting entry scan for in-use blob otherwise up point at
 	 * this blob note that ode, if non-zero, also represents a held dir page */
-	if (!(us = BlobScan(&tdc->f, (origOffset >> 5)))
-	    || !(nde = (struct DirEntry *)afs_dir_GetBlob(&tdc->f, us))) {
+	if (!(us = BlobScan(tdc, (origOffset >> 5)))
+	    || !(nde = (struct DirEntry *)afs_dir_GetBlob(tdc, us))) {
 	    /* failed to setup nde, return what we've got, and release ode */
 	    if (len) {
 		/* something to hand over. */
@@ -650,9 +733,9 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 		sdirEntry->d_fileno =
 		    (avc->fid.Fid.Volume << 16) + ntohl(ode->fid.vnode);
 		FIXUPSTUPIDINODE(sdirEntry->d_fileno);
-		sdirEntry->d_reclen = rlen = auio->afsio_resid;
+		sdirEntry->d_reclen = rlen = AFS_UIO_RESID(auio);
 		sdirEntry->d_namlen = o_slen;
-#if defined(AFS_SUN_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_HPUX100_ENV)
+#if defined(AFS_SUN5_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_HPUX100_ENV)
 		sdirEntry->d_off = origOffset;
 #endif
 		AFS_UIOMOVE((char *)sdirEntry, sizeof(*sdirEntry), UIO_READ,
@@ -680,11 +763,11 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #if defined(AFS_SUN5_ENV)
 					len, origOffset);
 #else
-					auio->afsio_resid, origOffset);
+					AFS_UIO_RESID(auio), origOffset);
 #endif
 #endif /* AFS_HPUX_ENV */
 #if !defined(AFS_SUN5_ENV)
-		auio->afsio_resid = 0;
+		AFS_UIO_SETRESID(auio, 0);
 #endif
 	    } else {
 		/* nothin to hand over */
@@ -708,9 +791,9 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #ifdef	AFS_SGI53_ENV
 	dirsiz =
 	    use64BitDirent ? DIRENTSIZE(n_slen) : IRIX5_DIRENTSIZE(n_slen);
-	if (dirsiz >= (auio->afsio_resid - len)) {
+	if (dirsiz >= (AFS_UIO_RESID(auio) - len)) {
 #else
-	if (DIRSIZ_LEN(n_slen) >= (auio->afsio_resid - len)) {
+	if (DIRSIZ_LEN(n_slen) >= (AFS_UIO_RESID(auio) - len)) {
 #endif /* AFS_SGI53_ENV */
 	    /* No can do no more now; ya know... at this time */
 	    DRelease((struct buffer *)nde, 0);	/* can't use this one. */
@@ -719,9 +802,9 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 		sdirEntry->d_fileno =
 		    (avc->fid.Fid.Volume << 16) + ntohl(ode->fid.vnode);
 		FIXUPSTUPIDINODE(sdirEntry->d_fileno);
-		sdirEntry->d_reclen = rlen = auio->afsio_resid;
+		sdirEntry->d_reclen = rlen = AFS_UIO_RESID(auio);
 		sdirEntry->d_namlen = o_slen;
-#if defined(AFS_SUN_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_HPUX100_ENV)
+#if defined(AFS_SUN5_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_HPUX100_ENV)
 		sdirEntry->d_off = origOffset;
 #endif
 		AFS_UIOMOVE((char *)sdirEntry, sizeof(*sdirEntry), UIO_READ,
@@ -747,12 +830,12 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #else /* AFS_HPUX_ENV */
 		code =
 		    afs_readdir_move(ode, avc, auio, o_slen,
-				     auio->afsio_resid, origOffset);
+				     AFS_UIO_RESID(auio), origOffset);
 #endif /* AFS_HPUX_ENV */
 		/* this next line used to be AFSVFS40 or AIX 3.1, but is
 		 * really generic */
-		auio->afsio_offset = origOffset;
-		auio->afsio_resid = 0;
+		AFS_UIO_SETOFFSET(auio, origOffset);
+		AFS_UIO_SETRESID(auio, 0);
 	    } else {		/* trouble, can't give anything to the user! */
 		/* even though he has given us a buffer, 
 		 * even though we have something to give us,
@@ -776,7 +859,7 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 	    FIXUPSTUPIDINODE(sdirEntry->d_fileno);
 	    sdirEntry->d_reclen = rlen = len;
 	    sdirEntry->d_namlen = o_slen;
-#if defined(AFS_SUN_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_HPUX100_ENV)
+#if defined(AFS_SUN5_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_HPUX100_ENV)
 	    sdirEntry->d_off = origOffset;
 #endif
 	    AFS_UIOMOVE((char *)sdirEntry, sizeof(*sdirEntry), UIO_READ, auio,
@@ -813,8 +896,7 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 	if (ode)
 	    DRelease((struct buffer *)ode, 0);
 	ode = nde;
-	auio->afsio_offset =
-	    (afs_int32) ((us + afs_dir_NameBlobs(nde->name)) << 5);
+	AFS_UIO_SETOFFSET(auio, (afs_int32) ((us + afs_dir_NameBlobs(nde->name)) << 5));
     }
     if (ode)
 	DRelease((struct buffer *)ode, 0);
@@ -928,12 +1010,12 @@ afs1_readdir(avc, auio, acred)
     auio->uio_fpflags = 0;
 #endif
     while (code == 0) {
-	origOffset = auio->afsio_offset;
+	origOffset = AFS_UIO_OFFSET(auio);
 
 	/* scan for the next interesting entry scan for in-use blob otherwise up point at
 	 * this blob note that ode, if non-zero, also represents a held dir page */
-	if (!(us = BlobScan(&tdc->f, (origOffset >> 5)))
-	    || !(nde = (struct DirEntry *)afs_dir_GetBlob(&tdc->f, us))) {
+	if (!(us = BlobScan(tdc, (origOffset >> 5)))
+	    || !(nde = (struct DirEntry *)afs_dir_GetBlob(tdc, us))) {
 	    /* failed to setup nde, return what we've got, and release ode */
 	    if (len) {
 		/* something to hand over. */
@@ -941,7 +1023,7 @@ afs1_readdir(avc, auio, acred)
 		sdirEntry->d_fileno =
 		    (avc->fid.Fid.Volume << 16) + ntohl(ode->fid.vnode);
 		FIXUPSTUPIDINODE(sdirEntry->d_fileno);
-		sdirEntry->d_reclen = rlen = auio->afsio_resid;
+		sdirEntry->d_reclen = rlen = AFS_UIO_RESID(auio);
 		sdirEntry->d_namlen = o_slen;
 		sdirEntry->d_off = origOffset;
 		AFS_UIOMOVE((char *)sdirEntry, sizeof(*sdirEntry), UIO_READ,
@@ -968,9 +1050,9 @@ afs1_readdir(avc, auio, acred)
 #else
 		code =
 		    afs_readdir_move(ode, avc, auio, o_slen,
-				     auio->afsio_resid, origOffset);
+				     AFS_UIO_RESID(auio), origOffset);
 #endif /* AFS_HPUX_ENV */
-		auio->afsio_resid = 0;
+		AFS_UIO_SETRESID(auio, 0);
 	    } else {
 		/* nothin to hand over */
 	    }
@@ -990,7 +1072,7 @@ afs1_readdir(avc, auio, acred)
 #else
 	n_slen = strlen(nde->name);
 #endif
-	if (NDIRSIZ_LEN(n_slen) >= (auio->afsio_resid - len)) {
+	if (NDIRSIZ_LEN(n_slen) >= (AFS_UIO_RESID(auio) - len)) {
 	    /* No can do no more now; ya know... at this time */
 	    DRelease(nde, 0);	/* can't use this one. */
 	    if (len) {
@@ -998,7 +1080,7 @@ afs1_readdir(avc, auio, acred)
 		sdirEntry->d_fileno =
 		    (avc->fid.Fid.Volume << 16) + ntohl(ode->fid.vnode);
 		FIXUPSTUPIDINODE(sdirEntry->d_fileno);
-		sdirEntry->d_reclen = rlen = auio->afsio_resid;
+		sdirEntry->d_reclen = rlen = AFS_UIO_RESID(auio);
 		sdirEntry->d_namlen = o_slen;
 		sdirEntry->d_off = origOffset;
 		AFS_UIOMOVE((char *)sdirEntry, sizeof(*sdirEntry), UIO_READ,
@@ -1024,11 +1106,11 @@ afs1_readdir(avc, auio, acred)
 #else
 		code =
 		    afs_readdir_move(ode, avc, auio, o_slen,
-				     auio->afsio_resid, origOffset);
+				     AFS_UIO_RESID(auio), origOffset);
 #endif /* AFS_HPUX_ENV */
 		/* this next line used to be AFSVFS40 or AIX 3.1, but is really generic */
-		auio->afsio_offset = origOffset;
-		auio->afsio_resid = 0;
+		AFS_UIO_SETOFFSET(auio, origOffset);
+		AFS_UIO_SETRESID(auio, 0);
 	    } else {		/* trouble, can't give anything to the user! */
 		/* even though he has given us a buffer, 
 		 * even though we have something to give us,
@@ -1081,7 +1163,7 @@ afs1_readdir(avc, auio, acred)
 	if (ode)
 	    DRelease(ode, 0);
 	ode = nde;
-	auio->afsio_offset = ((us + afs_dir_NameBlobs(nde->name)) << 5);
+	AFS_UIO_OFFSET(auio) = ((us + afs_dir_NameBlobs(nde->name)) << 5);
     }
     if (ode)
 	DRelease(ode, 0);
