@@ -1,5 +1,5 @@
 /* 
- * $Id: aklog_main.c,v 1.12.2.4 2007/02/10 13:58:17 jaltman Exp $
+ * $Id: aklog_main.c,v 1.12.2.5 2007/04/10 18:39:49 shadow Exp $
  *
  * Copyright 1990,1991 by the Massachusetts Institute of Technology
  * For distribution and copying rights, see the file "mit-copyright.h"
@@ -7,7 +7,7 @@
 
 #if !defined(lint) && !defined(SABER)
 static char *rcsid =
-	"$Id: aklog_main.c,v 1.12.2.4 2007/02/10 13:58:17 jaltman Exp $";
+	"$Id: aklog_main.c,v 1.12.2.5 2007/04/10 18:39:49 shadow Exp $";
 #endif /* lint || SABER */
 
 #include <afsconfig.h>
@@ -1557,23 +1557,6 @@ void aklog(int argc, char *argv[])
     exit(status);
 }
 
-#ifndef HAVE_ADD_TO_ERROR_TABLE
-
-#define error_table error_table_compat
-#include <afs/error_table.h>
-#undef error_table
-
-#ifndef HAVE_ADD_ERROR_TABLE
-void add_error_table (const struct error_table *);
-#endif /* !HAVE_ADD_ERROR_TABLE */
-
-void
-add_to_error_table(struct et_list *new_table)
-{
-	add_error_table((struct error_table *) new_table->table);
-}
-#endif /* HAVE_ADD_TO_ERROR_TABLE */
-
 static int isdir(char *path, unsigned char *val)
 {
     struct stat statbuf;
