@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/butc/recoverDb.c,v 1.9 2003/11/23 04:53:32 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/butc/recoverDb.c,v 1.13.4.1 2006/07/01 05:02:49 shadow Exp $");
 
 #include <stdio.h>
 #ifdef AFS_NT40_ENV
@@ -38,7 +38,6 @@ RCSID
 /* GLOBAL CONFIGURATION PARAMETERS */
 extern int autoQuery;
 extern int queryoperator;
-extern int isafile;
 
 /* Handle for the information read from all the tapes of a dump */
 afs_int32 tapepos;		/* when read a label, remember its position */
@@ -55,11 +54,11 @@ extern struct deviceSyncNode *deviceLatch;
 /* PrintDumpLabel
  *	print out the tape (dump) label.
  */
-
-PrintDumpLabel(labelptr)
-     struct butm_tapeLabel *labelptr;
+void
+PrintDumpLabel(struct butm_tapeLabel *labelptr)
 {
     char tapeName[BU_MAXTAPELEN + 32];
+    time_t t;
 
     printf("Dump label\n");
     printf("----------\n");
@@ -67,9 +66,12 @@ PrintDumpLabel(labelptr)
     printf("permanent tape name = %s\n", tapeName);
     TAPENAME(tapeName, labelptr->AFSName, labelptr->dumpid);
     printf("AFS tape name = %s\n", tapeName);
-    printf("creationTime = %s", ctime(&labelptr->creationTime));
-    if (labelptr->expirationDate)
-	printf("expirationDate = %s", cTIME(&labelptr->expirationDate));
+    t = labelptr->creationTime;
+    printf("creationTime = %s", ctime(&t));
+    if (labelptr->expirationDate) {
+        t = labelptr->expirationDate;
+	printf("expirationDate = %s", cTIME(&t));
+    }
     printf("cell = %s\n", labelptr->cell);
     printf("size = %u Kbytes\n", labelptr->size);
     printf("dump path = %s\n", labelptr->dumpPath);
@@ -84,10 +86,11 @@ PrintDumpLabel(labelptr)
 /* PrintVolumeHeader
  *	print the contents of a volume header. 
  */
-static
-PrintVolumeHeader(volHeader)
-     struct volumeHeader *volHeader;
+static void
+PrintVolumeHeader(struct volumeHeader *volHeader)
 {
+    time_t t;
+
     printf("-- volume --\n");
     printf("volume name: %s\n", volHeader->volumeName);
     printf("volume ID %d\n", volHeader->volumeID);
@@ -98,7 +101,8 @@ PrintVolumeHeader(volHeader)
     printf("parentID %d\n", volHeader->parentID);
     printf("endTime %d\n", volHeader->endTime);
     /* printf("versionflags %d\n", volHeader->versionflags); */
-    printf("clonedate %s\n", ctime(&volHeader->cloneDate));
+    t = volHeader->cloneDate;
+    printf("clonedate %s\n", ctime(&t));
 }
 
 /* Ask
@@ -109,8 +113,7 @@ PrintVolumeHeader(volHeader)
  */
 
 afs_int32
-Ask(st)
-     char *st;
+Ask(char *st)
 {
     int response;
 
@@ -128,205 +131,6 @@ Ask(st)
     }
 }
 
-/* Will read a dump, then see if there is a dump following it and
- * try to read that dump too.
- * The first tape label is the first dumpLabel.
- */
-readDumps(taskId, tapeInfoPtr, scanInfoPtr)
-     afs_uint32 taskId;
-     struct butm_tapeInfo *tapeInfoPtr;
-     struct tapeScanInfo *scanInfoPtr;
-{
-    afs_int32 code, c;
-
-    memcpy(&scanInfoPtr->dumpLabel, &scanInfoPtr->tapeLabel,
-	   sizeof(struct butm_tapeLabel));
-
-    while (1) {
-	code = readDump(taskId, tapeInfoPtr, scanInfoPtr);
-	if (code)
-	    ERROR_EXIT(code);
-
-	if (scanInfoPtr->tapeLabel.structVersion < TAPE_VERSION_4)
-	    break;
-
-	/* Remember the initial dump and see if appended dump exists */
-
-	if (!scanInfoPtr->initialDumpId)
-	    scanInfoPtr->initialDumpId = scanInfoPtr->dumpEntry.id;
-
-	c = butm_ReadLabel(tapeInfoPtr, &scanInfoPtr->dumpLabel, 0);	/* no rewind */
-	tapepos = tapeInfoPtr->position - 1;
-	if (c)
-	    break;
-    }
-
-  error_exit:
-    return (code);
-}
-
-afs_int32
-getScanTape(taskId, tapeInfoPtr, tname, tapeId, prompt, tapeLabelPtr)
-     afs_int32 taskId;
-     struct butm_tapeInfo *tapeInfoPtr;
-     char *tname;
-     afs_int32 tapeId;
-     int prompt;
-     struct butm_tapeLabel *tapeLabelPtr;
-{
-    afs_int32 code = 0;
-    int tapecount = 1;
-    afs_int32 curseq;
-    char tapename[BU_MAXTAPELEN + 32];
-    char gotname[BU_MAXTAPELEN + 32];
-
-    while (1) {
-	/* prompt for a tape */
-	if (prompt) {
-	    code =
-		PromptForTape(SCANOPCODE, tname, tapeId, taskId, tapecount);
-	    if (code)
-		ERROR_EXIT(code);
-	}
-	prompt = 1;
-	tapecount++;
-
-	code = butm_Mount(tapeInfoPtr, "");	/* open the tape device */
-	if (code) {
-	    TapeLog(0, taskId, code, tapeInfoPtr->error, "Can't open tape\n");
-	    goto newtape;
-	}
-
-	/* read the label on the tape */
-	code = butm_ReadLabel(tapeInfoPtr, tapeLabelPtr, 1);	/* rewind tape */
-	if (code) {
-	    ErrorLog(0, taskId, code, tapeInfoPtr->error,
-		     "Can't read tape label\n");
-	    goto newtape;
-	}
-	tapepos = tapeInfoPtr->position - 1;
-
-	/* Now check that the tape is good */
-	TAPENAME(tapename, tname, tapeId);
-	TAPENAME(gotname, tapeLabelPtr->AFSName, tapeLabelPtr->dumpid);
-
-	curseq = extractTapeSeq(tapeLabelPtr->AFSName);
-
-	/* Label can't be null or a bad name */
-	if (!strcmp(tapeLabelPtr->AFSName, "") || (curseq <= 0)) {
-	    TLog(taskId, "Expected tape with dump, label seen %s\n", gotname);
-	    goto newtape;
-	}
-
-	/* Label can't be a database tape */
-	if (databaseTape(tapeLabelPtr->AFSName)) {
-	    TLog(taskId,
-		 "Expected tape with dump. Can't scan database tape %s\n",
-		 gotname);
-	    goto newtape;
-	}
-
-	/* If no name, accept any tape */
-	if (strcmp(tname, "") == 0) {
-	    break;		/* Start scan on any tape */
-#ifdef notdef
-	    if (curseq == 1)
-		break;		/* The first tape */
-	    else {
-		TLog(taskId, "Expected first tape of dump, label seen %s\n",
-		     gotname);
-		goto newtape;
-	    }
-#endif
-	}
-
-	if (strcmp(tname, tapeLabelPtr->AFSName)
-	    || ((tapeLabelPtr->structVersion >= TAPE_VERSION_3)
-		&& (tapeLabelPtr->dumpid != tapeId))) {
-	    TLog(taskId, "Tape label expected %s, label seen %s\n", tapename,
-		 gotname);
-	    goto newtape;
-	}
-
-	/* We have the correct tape */
-	break;
-
-      newtape:
-	unmountTape(taskId, tapeInfoPtr);
-    }
-
-  error_exit:
-    return (code);
-}
-
-/* ScanDumps
- *	This set of code fragments read a tape, and add the information to
- * 	the database. Builds a literal structure.
- *	
- */
-
-ScanDumps(ptr)
-     struct scanTapeIf *ptr;
-{
-    struct butm_tapeInfo curTapeInfo;
-    struct tapeScanInfo tapeScanInfo;
-    afs_uint32 taskId;
-    afs_int32 code = 0;
-
-    taskId = ptr->taskId;
-    setStatus(taskId, DRIVE_WAIT);
-    EnterDeviceQueue(deviceLatch);
-    clearStatus(taskId, DRIVE_WAIT);
-
-    printf("\n\n");
-    if (ptr->addDbFlag)
-	TLog(taskId, "ScanTape and add to the database\n");
-    else
-	TLog(taskId, "Scantape\n");
-
-    memset(&tapeScanInfo, 0, sizeof(tapeScanInfo));
-    tapeScanInfo.addDbFlag = ptr->addDbFlag;
-
-    memset(&curTapeInfo, 0, sizeof(curTapeInfo));
-    curTapeInfo.structVersion = BUTM_MAJORVERSION;
-    code = butm_file_Instantiate(&curTapeInfo, &globalTapeConfig);
-    if (code) {
-	ErrorLog(0, taskId, code, curTapeInfo.error,
-		 "Can't initialize tape module\n");
-	ERROR_EXIT(code);
-    }
-
-    code =
-	getScanTape(taskId, &curTapeInfo, "", 0, autoQuery,
-		    &tapeScanInfo.tapeLabel);
-    if (code)
-	ERROR_EXIT(code);
-
-    code = readDumps(taskId, &curTapeInfo, &tapeScanInfo);
-    if (code)
-	ERROR_EXIT(code);
-
-  error_exit:
-    unmountTape(taskId, &curTapeInfo);
-    waitDbWatcher();
-
-    if (code == TC_ABORTEDBYREQUEST) {
-	ErrorLog(0, taskId, 0, 0, "Scantape: Aborted by request\n");
-	clearStatus(taskId, ABORT_REQUEST);
-	setStatus(taskId, ABORT_DONE);
-    } else if (code) {
-	ErrorLog(0, taskId, code, 0, "Scantape: Finished with errors\n");
-	setStatus(taskId, TASK_ERROR);
-    } else {
-	TLog(taskId, "Scantape: Finished\n");
-    }
-
-    free(ptr);
-    setStatus(taskId, TASK_DONE);
-    LeaveDeviceQueue(deviceLatch);
-    return (code);
-}
-
 /* scanVolData
  *	Skips the volume data on the tape. The end of the volume data is
  *	detected by the presence of the volume trailer or by an EOF indication
@@ -345,14 +149,8 @@ ScanDumps(ptr)
  */
 #define BIGCHUNK 102400
 
-static
-scanVolData(taskId, curTapePtr, tapeVersion, volumeHeader, volumeTrailer,
-	    bytesRead)
-     afs_int32 taskId;
-     struct butm_tapeInfo *curTapePtr;
-     afs_int32 tapeVersion;
-     struct volumeHeader *volumeHeader, *volumeTrailer;
-     afs_uint32 *bytesRead;
+static int
+scanVolData(afs_int32 taskId, struct butm_tapeInfo *curTapePtr, afs_int32 tapeVersion, struct volumeHeader *volumeHeader, struct volumeHeader *volumeTrailer, afs_uint32 *bytesRead)
 {
     afs_int32 headBytes, tailBytes;
     char *block = NULL;
@@ -483,8 +281,7 @@ scanVolData(taskId, curTapePtr, tapeVersion, volumeHeader, volumeTrailer,
  */
 
 char *
-nextTapeLabel(prevTapeName)
-     char *prevTapeName;
+nextTapeLabel(char *prevTapeName)
 {
     char *prevdot;
     char *retval;
@@ -524,11 +321,8 @@ nextTapeLabel(prevTapeName)
 
 afs_int32 RcreateDump();
 
-static
-readDump(taskId, tapeInfoPtr, scanInfoPtr)
-     afs_uint32 taskId;
-     struct butm_tapeInfo *tapeInfoPtr;
-     struct tapeScanInfo *scanInfoPtr;
+static int
+readDump(afs_uint32 taskId, struct butm_tapeInfo *tapeInfoPtr, struct tapeScanInfo *scanInfoPtr)
 {
     int moreTapes = 1;
     afs_int32 nbytes, flags, seq;
@@ -766,14 +560,205 @@ readDump(taskId, tapeInfoPtr, scanInfoPtr)
     return (code);
 }
 
+/* Will read a dump, then see if there is a dump following it and
+ * try to read that dump too.
+ * The first tape label is the first dumpLabel.
+ */
+int
+readDumps(afs_uint32 taskId, struct butm_tapeInfo *tapeInfoPtr, struct tapeScanInfo *scanInfoPtr)
+{
+    afs_int32 code, c;
+
+    memcpy(&scanInfoPtr->dumpLabel, &scanInfoPtr->tapeLabel,
+	   sizeof(struct butm_tapeLabel));
+
+    while (1) {
+	code = readDump(taskId, tapeInfoPtr, scanInfoPtr);
+	if (code)
+	    ERROR_EXIT(code);
+
+	if (scanInfoPtr->tapeLabel.structVersion < TAPE_VERSION_4)
+	    break;
+
+	/* Remember the initial dump and see if appended dump exists */
+
+	if (!scanInfoPtr->initialDumpId)
+	    scanInfoPtr->initialDumpId = scanInfoPtr->dumpEntry.id;
+
+	c = butm_ReadLabel(tapeInfoPtr, &scanInfoPtr->dumpLabel, 0);	/* no rewind */
+	tapepos = tapeInfoPtr->position - 1;
+	if (c)
+	    break;
+    }
+
+  error_exit:
+    return (code);
+}
+
+afs_int32
+getScanTape(afs_int32 taskId, struct butm_tapeInfo *tapeInfoPtr, char *tname, afs_int32 tapeId, int prompt, struct butm_tapeLabel *tapeLabelPtr)
+{
+    afs_int32 code = 0;
+    int tapecount = 1;
+    afs_int32 curseq;
+    char tapename[BU_MAXTAPELEN + 32];
+    char gotname[BU_MAXTAPELEN + 32];
+
+    while (1) {
+	/* prompt for a tape */
+	if (prompt) {
+	    code =
+		PromptForTape(SCANOPCODE, tname, tapeId, taskId, tapecount);
+	    if (code)
+		ERROR_EXIT(code);
+	}
+	prompt = 1;
+	tapecount++;
+
+	code = butm_Mount(tapeInfoPtr, "");	/* open the tape device */
+	if (code) {
+	    TapeLog(0, taskId, code, tapeInfoPtr->error, "Can't open tape\n");
+	    goto newtape;
+	}
+
+	/* read the label on the tape */
+	code = butm_ReadLabel(tapeInfoPtr, tapeLabelPtr, 1);	/* rewind tape */
+	if (code) {
+	    ErrorLog(0, taskId, code, tapeInfoPtr->error,
+		     "Can't read tape label\n");
+	    goto newtape;
+	}
+	tapepos = tapeInfoPtr->position - 1;
+
+	/* Now check that the tape is good */
+	TAPENAME(tapename, tname, tapeId);
+	TAPENAME(gotname, tapeLabelPtr->AFSName, tapeLabelPtr->dumpid);
+
+	curseq = extractTapeSeq(tapeLabelPtr->AFSName);
+
+	/* Label can't be null or a bad name */
+	if (!strcmp(tapeLabelPtr->AFSName, "") || (curseq <= 0)) {
+	    TLog(taskId, "Expected tape with dump, label seen %s\n", gotname);
+	    goto newtape;
+	}
+
+	/* Label can't be a database tape */
+	if (databaseTape(tapeLabelPtr->AFSName)) {
+	    TLog(taskId,
+		 "Expected tape with dump. Can't scan database tape %s\n",
+		 gotname);
+	    goto newtape;
+	}
+
+	/* If no name, accept any tape */
+	if (strcmp(tname, "") == 0) {
+	    break;		/* Start scan on any tape */
+#ifdef notdef
+	    if (curseq == 1)
+		break;		/* The first tape */
+	    else {
+		TLog(taskId, "Expected first tape of dump, label seen %s\n",
+		     gotname);
+		goto newtape;
+	    }
+#endif
+	}
+
+	if (strcmp(tname, tapeLabelPtr->AFSName)
+	    || ((tapeLabelPtr->structVersion >= TAPE_VERSION_3)
+		&& (tapeLabelPtr->dumpid != tapeId))) {
+	    TLog(taskId, "Tape label expected %s, label seen %s\n", tapename,
+		 gotname);
+	    goto newtape;
+	}
+
+	/* We have the correct tape */
+	break;
+
+      newtape:
+	unmountTape(taskId, tapeInfoPtr);
+    }
+
+  error_exit:
+    return (code);
+}
+
+/* ScanDumps
+ *	This set of code fragments read a tape, and add the information to
+ * 	the database. Builds a literal structure.
+ *	
+ */
+
+int
+ScanDumps(struct scanTapeIf *ptr)
+{
+    struct butm_tapeInfo curTapeInfo;
+    struct tapeScanInfo tapeScanInfo;
+    afs_uint32 taskId;
+    afs_int32 code = 0;
+
+    taskId = ptr->taskId;
+    setStatus(taskId, DRIVE_WAIT);
+    EnterDeviceQueue(deviceLatch);
+    clearStatus(taskId, DRIVE_WAIT);
+
+    printf("\n\n");
+    if (ptr->addDbFlag)
+	TLog(taskId, "ScanTape and add to the database\n");
+    else
+	TLog(taskId, "Scantape\n");
+
+    memset(&tapeScanInfo, 0, sizeof(tapeScanInfo));
+    tapeScanInfo.addDbFlag = ptr->addDbFlag;
+
+    memset(&curTapeInfo, 0, sizeof(curTapeInfo));
+    curTapeInfo.structVersion = BUTM_MAJORVERSION;
+    code = butm_file_Instantiate(&curTapeInfo, &globalTapeConfig);
+    if (code) {
+	ErrorLog(0, taskId, code, curTapeInfo.error,
+		 "Can't initialize tape module\n");
+	ERROR_EXIT(code);
+    }
+
+    code =
+	getScanTape(taskId, &curTapeInfo, "", 0, autoQuery,
+		    &tapeScanInfo.tapeLabel);
+    if (code)
+	ERROR_EXIT(code);
+
+    code = readDumps(taskId, &curTapeInfo, &tapeScanInfo);
+    if (code)
+	ERROR_EXIT(code);
+
+  error_exit:
+    unmountTape(taskId, &curTapeInfo);
+    waitDbWatcher();
+
+    if (code == TC_ABORTEDBYREQUEST) {
+	ErrorLog(0, taskId, 0, 0, "Scantape: Aborted by request\n");
+	clearStatus(taskId, ABORT_REQUEST);
+	setStatus(taskId, ABORT_DONE);
+    } else if (code) {
+	ErrorLog(0, taskId, code, 0, "Scantape: Finished with errors\n");
+	setStatus(taskId, TASK_ERROR);
+    } else {
+	TLog(taskId, "Scantape: Finished\n");
+    }
+
+    free(ptr);
+    setStatus(taskId, TASK_DONE);
+    LeaveDeviceQueue(deviceLatch);
+    return (code);
+}
+
+
 /* validatePath
  * exit:
  *	0 - not ok
  *	1 - ok
  */
-validatePath(labelptr, pathptr)
-     struct butm_tapeLabel *labelptr;
-     char *pathptr;
+int
+validatePath(struct butm_tapeLabel *labelptr, char *pathptr)
 {
     char *up, *tp;
     char tapeName[BU_MAXTAPELEN];
@@ -821,8 +806,7 @@ validatePath(labelptr, pathptr)
  */
 
 char *
-volumesetNamePtr(ptr)
-     char *ptr;
+volumesetNamePtr(char *ptr)
 {
     static char vsname[BU_MAXUNAMELEN];
     char *dotPtr;
@@ -843,8 +827,7 @@ volumesetNamePtr(ptr)
 }
 
 char *
-extractDumpName(ptr)
-     char *ptr;
+extractDumpName(char *ptr)
 {
     static char dname[BU_MAXTAPELEN];
     char *dotPtr;
@@ -875,8 +858,8 @@ extractDumpName(ptr)
  *	-1 - error, couldn't extract sequence number
  */
 
-extractTapeSeq(tapename)
-     char *tapename;
+int
+extractTapeSeq(char *tapename)
 {
     char *sptr;
 
@@ -892,8 +875,7 @@ extractTapeSeq(tapename)
  *   a database tape or not.
  */
 int
-databaseTape(tapeName)
-     char *tapeName;
+databaseTape(char *tapeName)
 {
     char *sptr;
     int c;
@@ -902,7 +884,7 @@ databaseTape(tapeName)
     if (!sptr)
 	return (0);
 
-    c = (int)((afs_int32) sptr - (afs_int32) tapeName);
+    c = (int)((char *) sptr - (char *) tapeName);
     if (strncmp(tapeName, DUMP_TAPE_NAME, c) == 0)
 	return (1);
 
@@ -910,9 +892,7 @@ databaseTape(tapeName)
 }
 
 afs_int32
-RcreateDump(tapeScanInfoPtr, volHeaderPtr)
-     struct tapeScanInfo *tapeScanInfoPtr;
-     struct volumeHeader *volHeaderPtr;
+RcreateDump(struct tapeScanInfo *tapeScanInfoPtr, struct volumeHeader *volHeaderPtr)
 {
     afs_int32 code;
     struct butm_tapeLabel *dumpLabelPtr = &tapeScanInfoPtr->dumpLabel;
