@@ -12,7 +12,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/db_verify.c,v 1.15 2004/04/18 06:13:50 kolya Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/db_verify.c,v 1.16.14.1 2007/04/10 18:39:54 shadow Exp $");
 
 /*
  *                      (3) Define a structure, idused, instead of an
@@ -57,6 +57,7 @@ RCSID
 #include <afs/afsutil.h>
 #include <ubik.h>
 #include <afs/cmd.h>
+#include <afs/com_err.h>
 
 #include "ptint.h"
 #include "pterror.h"
@@ -69,8 +70,7 @@ char *whoami = "db_verify";
 #define UBIK_HEADERSIZE 64
 
 afs_int32
-printheader(h)
-     struct prheader *h;
+printheader(struct prheader *h)
 {
     printf("Version           = %d\n", ntohl(h->version));
     printf("Header Size       = %d\n", ntohl(h->headerSize));
@@ -91,10 +91,7 @@ printheader(h)
 }
 
 static afs_int32
-pr_Read(pos, buff, len)
-     afs_int32 pos;
-     char *buff;
-     afs_int32 len;
+pr_Read(afs_int32 pos, char *buff, afs_int32 len)
 {
     afs_int32 code;
 
@@ -125,7 +122,7 @@ ReadHeader()
 
     code = pr_Read(0, (char *)&cheader, sizeof(cheader));
     if (code) {
-	com_err(whoami, code, "couldn't read header");
+	afs_com_err(whoami, code, "couldn't read header");
 	return code;
     }
     /* Check and see if database exists and is approximately OK. */
@@ -133,23 +130,21 @@ ReadHeader()
 	|| ntohl(cheader.eofPtr) == 0) {
 	if (code)
 	    return code;
-	com_err(whoami, PRDBBAD, "header is bad");
+	afs_com_err(whoami, PRDBBAD, "header is bad");
 	return PRDBBAD;
     }
     return 0;
 }
 
 static afs_int32
-IDHash(x)
-     afs_int32 x;
+IDHash(afs_int32 x)
 {
     /* returns hash bucket for x */
     return ((abs(x)) % HASHSIZE);
 }
 
 static afs_int32
-NameHash(aname)
-     register unsigned char *aname;
+NameHash(register unsigned char *aname)
 {
     /* returns hash bucket for aname */
     register unsigned int hash = 0;
@@ -208,8 +203,7 @@ int idcount(struct idused **idmapp, int id);
 #endif
 
 int
-readUbikHeader(misc)
-     struct misc_data *misc;
+readUbikHeader(struct misc_data *misc)
 {
     int offset, r;
     struct ubik_hdr uheader;
@@ -252,9 +246,7 @@ readUbikHeader(misc)
 }
 
 afs_int32
-ConvertDiskAddress(ea, eiP)
-     afs_uint32 ea;
-     int *eiP;
+ConvertDiskAddress(afs_uint32 ea, int *eiP)
 {
     int i;
 
@@ -274,11 +266,7 @@ ConvertDiskAddress(ea, eiP)
 }
 
 int
-PrintEntryError(misc, ea, e, indent)
-     struct misc_data *misc;
-     afs_int32 ea;
-     struct prentry *e;
-     int indent;
+PrintEntryError(struct misc_data *misc, afs_int32 ea, struct prentry *e, int indent)
 {
 
     pr_PrintEntry(stderr, /*net order */ 0, ea, e, indent);
@@ -286,11 +274,10 @@ PrintEntryError(misc, ea, e, indent)
 }
 
 afs_int32
-WalkHashTable(hashtable, hashType, map, misc)
-     afs_int32 hashtable[];	/* hash table to walk */
-     int hashType;		/* hash function to use */
-     char map[];		/* one byte per db entry */
-     struct misc_data *misc;	/* stuff to keep track of */
+WalkHashTable(afs_int32 hashtable[],	/* hash table to walk */
+	      int hashType,		/* hash function to use */
+	      char map[],		/* one byte per db entry */
+	      struct misc_data *misc)	/* stuff to keep track of */
 {
     afs_int32 code;
     int hi;			/* index in hash table */
@@ -404,11 +391,9 @@ WalkHashTable(hashtable, hashType, map, misc)
 }
 
 afs_int32
-WalkNextChain(map, misc, ea, e)
-     char map[];		/* one byte per db entry */
-     struct misc_data *misc;	/* stuff to keep track of */
-     afs_int32 ea;
-     struct prentry *e;
+WalkNextChain(char map[],		/* one byte per db entry */
+	      struct misc_data *misc,	/* stuff to keep track of */
+	      afs_int32 ea, struct prentry *e)
 {
     afs_int32 head;
     int bit;
@@ -725,11 +710,9 @@ WalkNextChain(map, misc, ea, e)
 }
 
 afs_int32
-WalkOwnedChain(map, misc, ea, e)
-     char map[];		/* one byte per db entry */
-     struct misc_data *misc;	/* stuff to keep track of */
-     afs_int32 ea;
-     struct prentry *e;
+WalkOwnedChain(char map[],		/* one byte per db entry */
+	       struct misc_data *misc,	/* stuff to keep track of */
+	       afs_int32 ea, struct prentry *e)
 {
     afs_int32 head;
     afs_int32 code;
@@ -809,9 +792,8 @@ WalkOwnedChain(map, misc, ea, e)
 }
 
 afs_int32
-WalkChains(map, misc)
-     char map[];		/* one byte per db entry */
-     struct misc_data *misc;	/* stuff to keep track of */
+WalkChains(char map[],		/* one byte per db entry */
+	   struct misc_data *misc)	/* stuff to keep track of */
 {
     afs_int32 code;
     int ei;
@@ -924,9 +906,7 @@ WalkChains(map, misc)
 }
 
 afs_int32
-GC(map, misc)
-     char map[];
-     struct misc_data *misc;
+GC(char map[], struct misc_data *misc)
 {
     afs_int32 code;
     int ei;
@@ -958,13 +938,14 @@ GC(map, misc)
 	    id = ntohl(e.id);
 #if defined(SUPERGROUPS)
 	    if ((id != ANONYMOUSID)
-		&& ((refCount = idcount(&misc->idmap, id)) != ntohl(e.count))) {
+		&& ((refCount = idcount(&misc->idmap, id)) != ntohl(e.count))) 
 #else
 	    if ((id >= misc->minId) && (id <= misc->maxId)
 		&& (id != ANONYMOUSID)
 		&& ((refCount = misc->idmap[id - misc->minId]) !=
-		    ntohl(e.count))) {
+		    ntohl(e.count))) 
 #endif /* SUPERGROUPS */
+	      {
 		afs_int32 na;
 		fprintf(stderr,
 			"Entry membership count is inconsistent: %d entries refer to this one\n",
@@ -991,8 +972,7 @@ GC(map, misc)
 }
 
 char *
-QuoteName(s)
-     char *s;
+QuoteName(char *s)
 {
     char *qs;
     if (strpbrk(s, " \t")) {
@@ -1006,9 +986,7 @@ QuoteName(s)
 }
 
 afs_int32
-DumpRecreate(map, misc)
-     char map[];
-     struct misc_data *misc;
+DumpRecreate(char map[], struct misc_data *misc)
 {
     afs_int32 code;
     int ei;
@@ -1069,10 +1047,11 @@ DumpRecreate(map, misc)
 		/* check for duplicate id.  This may still lead to duplicate
 		 * names. */
 #if defined(SUPERGROUPS)
-		if (idcount(&idmap, id)) {
+		if (idcount(&idmap, id)) 
 #else
-		if (idmap[id - misc->minId]) {
+		if (idmap[id - misc->minId]) 
 #endif
+		  {
 		    fprintf(stderr, "Skipping entry with duplicate id %di\n",
 			    id);
 		    goto user_done;
@@ -1179,10 +1158,11 @@ DumpRecreate(map, misc)
 
 	    owner = ntohl(e.owner);
 #if defined(SUPERGROUPS)
-	    if (!idcount(&idmap, owner)) {
+	    if (!idcount(&idmap, owner)) 
 #else
-	    if (idmap[owner - misc->minId] == 0) {
+	    if (idmap[owner - misc->minId] == 0) 
 #endif
+	      {
 		fprintf(stderr,
 			"Skipping chown of '%s' to non-existant owner %di\n",
 			e.name, owner);
@@ -1310,8 +1290,7 @@ DumpRecreate(map, misc)
 }
 
 afs_int32
-CheckPrDatabase(misc)
-     struct misc_data *misc;	/* info & statistics */
+CheckPrDatabase(struct misc_data *misc)	/* info & statistics */
 {
     afs_int32 code;
     afs_int32 eof;
@@ -1323,7 +1302,7 @@ CheckPrDatabase(misc)
     n = eof / sizeof(struct prentry);
     if ((eof < 0) || (n * sizeof(struct prentry) != eof)) {
 	code = PRDBBAD;
-	com_err(whoami, code, "eof ptr no good: eof=%d, sizeof(prentry)=%d",
+	afs_com_err(whoami, code, "eof ptr no good: eof=%d, sizeof(prentry)=%d",
 		eof, sizeof(struct prentry));
       abort:
 	return code;
@@ -1340,7 +1319,7 @@ CheckPrDatabase(misc)
     }
     code = WalkHashTable(cheader.nameHash, MAP_NAMEHASH, map, misc);
     if (code) {
-	com_err(whoami, code, "walking name hash");
+	afs_com_err(whoami, code, "walking name hash");
 	goto abort;
     }
     if (misc->verbose) {
@@ -1349,7 +1328,7 @@ CheckPrDatabase(misc)
     }
     code = WalkHashTable(cheader.idHash, MAP_IDHASH, map, misc);
     if (code) {
-	com_err(whoami, code, "walking id hash");
+	afs_com_err(whoami, code, "walking id hash");
 	goto abort;
     }
 
@@ -1361,7 +1340,7 @@ CheckPrDatabase(misc)
     misc->idRange = n - misc->minId + 1;
     misc->idmap = (afs_int32 *) malloc(misc->idRange * sizeof(afs_int32));
     if (!misc->idmap) {
-	com_err(whoami, 0, "Unable to malloc space for max ids of %d",
+	afs_com_err(whoami, 0, "Unable to malloc space for max ids of %d",
 		misc->idRange);
 	code = -1;
 	goto abort;
@@ -1375,7 +1354,7 @@ CheckPrDatabase(misc)
     }
     code = WalkChains(map, misc);
     if (code) {
-	com_err(whoami, code, "walking chains");
+	afs_com_err(whoami, code, "walking chains");
 	goto abort;
     }
     if (misc->verbose) {
@@ -1384,7 +1363,7 @@ CheckPrDatabase(misc)
     }
     code = WalkNextChain(map, misc, 0, 0);
     if (code) {
-	com_err(whoami, code, "walking free list");
+	afs_com_err(whoami, code, "walking free list");
 	goto abort;
     }
     if (misc->verbose) {
@@ -1393,7 +1372,7 @@ CheckPrDatabase(misc)
     }
     code = WalkOwnedChain(map, misc, 0, 0);
     if (code) {
-	com_err(whoami, code, "walking orphan list");
+	afs_com_err(whoami, code, "walking orphan list");
 	goto abort;
     }
 
@@ -1403,7 +1382,7 @@ CheckPrDatabase(misc)
     }
     code = GC(map, misc);
     if (code) {
-	com_err(whoami, code, "looking for unreferenced entries");
+	afs_com_err(whoami, code, "looking for unreferenced entries");
 	goto abort;
     }
 
@@ -1450,12 +1429,11 @@ CheckPrDatabase(misc)
     free(map);
     return code;
 }
-
+    
 #include "AFS_component_version_number.c"
 
-WorkerBee(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+WorkerBee(struct cmd_syndesc *as, char *arock)
 {
     afs_int32 code;
     char *recreateFile;
@@ -1476,7 +1454,7 @@ WorkerBee(as, arock)
 
     fd = open(pr_dbaseName, O_RDONLY, 0);
     if (fd == -1) {
-	com_err(whoami, errno, "Open failed on db %s", pr_dbaseName);
+	afs_com_err(whoami, errno, "Open failed on db %s", pr_dbaseName);
 	exit(2);
     }
 
@@ -1494,7 +1472,7 @@ WorkerBee(as, arock)
     if (recreateFile) {
 	misc.recreate = fopen(recreateFile, "w");
 	if (misc.recreate == 0) {
-	    com_err(whoami, errno,
+	    afs_com_err(whoami, errno,
 		    "can't create file for recreation instructions: %s",
 		    recreateFile);
 	    exit(4);
@@ -1502,15 +1480,14 @@ WorkerBee(as, arock)
     }
     code = CheckPrDatabase(&misc);
     if (code) {
-	com_err(whoami, code, "Checking prserver database");
+	afs_com_err(whoami, code, "Checking prserver database");
 	exit(3);
     }
     exit(0);
 }
 
-main(argc, argv)
-     int argc;
-     char *argv[];
+int
+main(int argc, char *argv[])
 {
     struct cmd_syndesc *ts;
 
@@ -1536,8 +1513,7 @@ main(argc, argv)
 /* new routines to deal with very large ID numbers */
 
 void
-zeromap(idmap)
-     struct idused *idmap;
+zeromap(struct idused *idmap)
 {
     while (idmap) {
 	bzero((char *)idmap->idcount, sizeof idmap->idcount);
@@ -1574,8 +1550,7 @@ inccount(struct idused **idmapp, int id)
 }
 
 int
-idcount(idmapp, id)
-     struct idused **idmapp;
+idcount(struct idused **idmapp, int id)
 {
     struct idused *idmap;
 
@@ -1591,5 +1566,4 @@ idcount(idmapp, id)
     }
     return 0;
 }
-
 #endif /* SUPERGROUPS */
