@@ -112,7 +112,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/ptserver.c,v 1.24 2006/02/01 16:09:19 shadow Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/ptserver.c,v 1.25.2.4 2007/04/10 18:39:54 shadow Exp $");
 
 #include <afs/stds.h>
 #ifdef	AFS_AIX32_ENV
@@ -148,6 +148,7 @@ RCSID
 #include "error_macros.h"
 #include "afs/audit.h"
 #include <afs/afsutil.h>
+#include <afs/com_err.h>
 
 
 /* make	all of these into a structure if you want */
@@ -166,6 +167,11 @@ int pr_realmNameLen;
 char *pr_realmName;
 
 int restricted = 0;
+int rxMaxMTU = -1;
+int rxBind = 0;
+
+#define ADDRSPERSITE 16         /* Same global is in rx/rx_user.c */
+afs_uint32 SHostAddrs[ADDRSPERSITE];
 
 static struct afsconf_cell info;
 
@@ -221,6 +227,7 @@ main(int argc, char **argv)
     int kerberosKeys;		/* set if found some keys */
     int lwps = 3;
     char clones[MAXHOSTSPERCELL];
+    afs_uint32 host = htonl(INADDR_ANY);
 
     const char *pr_dbaseName;
     char *whoami = "ptserver";
@@ -304,6 +311,9 @@ main(int argc, char **argv)
 	else if (strncmp(arg, "-restricted", alen) == 0) {
 	    restricted = 1;
 	}
+	else if (strncmp(arg, "-rxbind", alen) == 0) {
+	    rxBind = 1;
+	}
 	else if (strncmp(arg, "-enable_peer_stats", alen) == 0) {
 	    rx_enablePeerRPCStats();
 	} else if (strncmp(arg, "-enable_process_stats", alen) == 0) {
@@ -349,6 +359,20 @@ main(int argc, char **argv)
 	    } else
 		printf("Warning: auditlog %s not writable, ignored.\n", fileName);
 	}
+	else if (!strncmp(arg, "-rxmaxmtu", alen)) {
+	    if ((a + 1) >= argc) {
+		fprintf(stderr, "missing argument for -rxmaxmtu\n");
+		PT_EXIT(1);
+	    }
+	    rxMaxMTU = atoi(argv[++a]);
+	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) ||
+		 (rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
+		printf("rxMaxMTU %d% invalid; must be between %d-%d\n",
+			rxMaxMTU, RX_MIN_PACKET_SIZE,
+			RX_MAX_PACKET_DATA_SIZE);
+		PT_EXIT(1);
+	    }
+	} 
 	else if (*arg == '-') {
 	    /* hack in help flag support */
 
@@ -359,16 +383,16 @@ main(int argc, char **argv)
 		   "[-syslog[=FACILITY]] "
 		   "[-p <number of processes>] [-rebuild] "
 		   "[-groupdepth <depth>] "
-		   "[-restricted] "
+		   "[-restricted] [-rxmaxmtu <bytes>] [-rxbind] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-default_access default_user_access default_group_access] "
 		   "[-help]\n");
 #else /* AFS_NT40_ENV */
 	    printf("Usage: ptserver [-database <db path>] "
 		   "[-auditlog <log path>] "
-		   "[-p <number of processes>] [-rebuild] "
+		   "[-p <number of processes>] [-rebuild] [-rxbind] "
 		   "[-default_access default_user_access default_group_access] "
-		   "[-restricted] "
+		   "[-restricted] [-rxmaxmtu <bytes>] [-rxbind] "
 		   "[-groupdepth <depth>] " "[-help]\n");
 #endif
 #else
@@ -379,13 +403,13 @@ main(int argc, char **argv)
 		   "[-p <number of processes>] [-rebuild] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-default_access default_user_access default_group_access] "
-		   "[-restricted] "
+		   "[-restricted] [-rxmaxmtu <bytes>] [-rxbind] "
 		   "[-help]\n");
 #else /* AFS_NT40_ENV */
 	    printf("Usage: ptserver [-database <db path>] "
 		   "[-auditlog <log path>] "
 		   "[-default_access default_user_access default_group_access] "
-		   "[-restricted] "
+		   "[-restricted] [-rxmaxmtu <bytes>] [-rxbind] "
 		   "[-p <number of processes>] [-rebuild] " "[-help]\n");
 #endif
 #endif
@@ -436,7 +460,7 @@ main(int argc, char **argv)
     code =
 	afsconf_GetExtendedCellInfo(prdir, NULL, "afsprot", &info, &clones);
     if (code) {
-	com_err(whoami, code, "Couldn't get server list");
+	afs_com_err(whoami, code, "Couldn't get server list");
 	PT_EXIT(2);
     }
     pr_realmName = info.name;
@@ -446,7 +470,7 @@ main(int argc, char **argv)
     /* get keys */
     code = afsconf_GetKey(prdir, 999, &tkey);
     if (code) {
-	com_err(whoami, code,
+	afs_com_err(whoami, code,
 		"couldn't get bcrypt keys from key file, ignoring.");
     }
 #endif
@@ -478,11 +502,33 @@ main(int argc, char **argv)
      * and the header are in separate Ubik buffers then 120 buffers may be
      * required. */
     ubik_nBuffers = 120 + /*fudge */ 40;
+
+    if (rxBind) {
+	afs_int32 ccode;
+#ifndef AFS_NT40_ENV
+	if (AFSDIR_SERVER_NETRESTRICT_FILEPATH || 
+	    AFSDIR_SERVER_NETINFO_FILEPATH) {
+	    char reason[1024];
+	    ccode = parseNetFiles(SHostAddrs, NULL, NULL,
+					   ADDRSPERSITE, reason,
+					   AFSDIR_SERVER_NETINFO_FILEPATH,
+					   AFSDIR_SERVER_NETRESTRICT_FILEPATH);
+	} else 
+#endif
+	{
+	    ccode = rx_getAllAddr(SHostAddrs, ADDRSPERSITE);
+	}
+	if (ccode == 1) {
+	    host = SHostAddrs[0];
+	    rx_InitHost(host, htons(AFSCONF_PROTPORT));
+	}
+    }
+
     code =
 	ubik_ServerInitByInfo(myHost, htons(AFSCONF_PROTPORT), &info, &clones,
 			      pr_dbaseName, &dbase);
     if (code) {
-	com_err(whoami, code, "Ubik init failed");
+	afs_com_err(whoami, code, "Ubik init failed");
 	PT_EXIT(2);
     }
 #if defined(SUPERGROUPS)
@@ -499,8 +545,12 @@ main(int argc, char **argv)
     /* Disable jumbograms */
     rx_SetNoJumbo();
 
+    if (rxMaxMTU != -1) {
+	rx_SetMaxMTU(rxMaxMTU);
+    }
+
     tservice =
-	rx_NewService(0, PRSRV, "Protection Server", sc, 3,
+	rx_NewServiceHost(host, 0, PRSRV, "Protection Server", sc, 3,
 		      PR_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
 	fprintf(stderr, "ptserver: Could not create new rx service.\n");
@@ -510,7 +560,7 @@ main(int argc, char **argv)
     rx_SetMaxProcs(tservice, lwps);
 
     tservice =
-	rx_NewService(0, RX_STATS_SERVICE_ID, "rpcstats", sc, 3,
+	rx_NewServiceHost(host, 0, RX_STATS_SERVICE_ID, "rpcstats", sc, 3,
 		      RXSTATS_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
 	fprintf(stderr, "ptserver: Could not create new rx service.\n");
