@@ -19,7 +19,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/vfsck/setup.c,v 1.9 2003/07/15 23:17:27 shadow Exp $");
+    ("$Header: /cvs/openafs/src/vfsck/setup.c,v 1.13 2005/04/03 18:09:32 shadow Exp $");
 
 #include <stdio.h>
 #define VICE
@@ -129,9 +129,6 @@ setup(dev)
     mlk_pbp = 0;
     pbp = 0;
     mlk_startinum = 0;
-#ifdef	AFS_DEC_ENV
-    iscorrupt = 0;
-#endif
 #if defined(ACLS) && defined(AFS_HPUX_ENV)
     n_cont = 0;
 #endif
@@ -359,17 +356,6 @@ setup(dev)
 	    sbdirty();
 	}
     }
-#ifdef	AFS_DEC_ENV
-    /*
-     * If '-p' is used and the partition was cleanly unmounted last time then skip the
-     * fscking process
-     */
-    if (only_when_needed && (sblock.fs_clean == FS_CLEAN)
-	&& clean_byte_valid(sblock.fs_lastfsck)) {
-	msgprintf("%s: umounted cleanly\n", dev);
-	return (FS_CLEAN);
-    }
-#endif
 #ifdef	AFS_HPUX_ENV
     /*
      * Do we need to continue ?
@@ -380,6 +366,7 @@ setup(dev)
 	return (-1);
 #endif
 #ifdef AFS_NEWCG_ENV
+# ifndef AFS_SUN59_ENV
     if (sblock.fs_interleave < 1) {
 	pwarn("IMPOSSIBLE INTERLEAVE=%d IN SUPERBLOCK", sblock.fs_interleave);
 	sblock.fs_interleave = 1;
@@ -390,6 +377,7 @@ setup(dev)
 	    dirty(&asblk);
 	}
     }
+# endif /* AFS_SUN59_ENV */
 #endif /* AFS_NEWCG_ENV */
 #ifdef AFS_NEWCG_ENV
     if (sblock.fs_npsect < sblock.fs_nsect) {
@@ -471,7 +459,9 @@ setup(dev)
 #if	defined(AFS_SUN_ENV) && !defined(AFS_SUN3_ENV)
 #ifdef	AFS_SUN5_ENV
 	    sblock.fs_npsect = 0;
+# ifndef AFS_SUN59_ENV
 	    sblock.fs_interleave = 0;
+# endif
 	    sblock.fs_state = FSOKAY - sblock.fs_time;	/* make mountable */
 #else
 	    fs_set_state(&sblock, FSOKAY - sblock.fs_time);
@@ -726,20 +716,19 @@ readsb(listerr)
 #ifndef	AFS_HPUX_ENV
     memcpy((char *)altsblock.fs_sparecon, (char *)sblock.fs_sparecon,
 	   sizeof sblock.fs_sparecon);
-#endif
-#if defined(AFS_DEC_ENV)
-    memcpy((char *)altsblock.fs_extra, (char *)sblock.fs_extra,
-	   sizeof sblock.fs_extra);
-    altsblock.fs_deftimer = sblock.fs_deftimer;
-    altsblock.fs_lastfsck = sblock.fs_lastfsck;
-    altsblock.fs_gennum = sblock.fs_gennum;
 #endif
     /*
      * The following should not have to be copied.
      */
     altsblock.fs_fsbtodb = sblock.fs_fsbtodb;
 #ifdef AFS_NEWCG_ENV
+# if defined(AFS_SUN59_ENV) && defined(FS_SI_OK)
+    /* fs_interleave replaced with fs_si and FS_SI_OK defined in */
+    /* ufs_fs.h version 2.63 don't need to compare either */
+    altsblock.fs_si = sblock.fs_si;
+# else
     altsblock.fs_interleave = sblock.fs_interleave;
+# endif
     altsblock.fs_npsect = sblock.fs_npsect;
     altsblock.fs_nrpos = sblock.fs_nrpos;
 #endif /* AFS_NEWCG_ENV */
@@ -791,27 +780,6 @@ calcsb(dev, devfd, fs)
     return 0;
 }
 
-#ifdef	AFS_DEC_ENV
-clean_byte_valid(lastfsck)
-     time_t lastfsck;
-{
-    time_t now;
-    int delta;
-
-    time(&now);
-    if ((!sblock.fs_deftimer) || (!sblock.fs_lastfsck) || (lastfsck > now)) {
-	sblock.fs_deftimer = 0;
-	return (0);
-    }
-    if (!sblock.fs_cleantimer)
-	return (0);
-    delta = (now - lastfsck) / 86400;
-    if (delta > 60)
-	return (0);
-    return (1);
-}
-#endif
-
 #include <sys/ustat.h>
 #ifdef	AFS_HPUX_ENV
 #include <sys/pstat.h>
